@@ -10,11 +10,23 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IInspectable as _IInspectable_051e6ed8)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_eventschemas.CfnDiscoverer"):
+class CfnDiscoverer(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_eventschemas.CfnDiscoverer",
+):
     """A CloudFormation ``AWS::EventSchemas::Discoverer``.
 
     see
@@ -22,7 +34,16 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
     cloudformationResource:
     :cloudformationResource:: AWS::EventSchemas::Discoverer
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, source_arn: str, description: typing.Optional[str]=None, tags: typing.Optional[typing.List["TagsEntryProperty"]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        source_arn: str,
+        description: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
+    ) -> None:
         """Create a new ``AWS::EventSchemas::Discoverer``.
 
         :param scope: - scope in which this resource is defined.
@@ -31,13 +52,22 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
         :param description: ``AWS::EventSchemas::Discoverer.Description``.
         :param tags: ``AWS::EventSchemas::Discoverer.Tags``.
         """
-        props = CfnDiscovererProps(source_arn=source_arn, description=description, tags=tags)
+        props = CfnDiscovererProps(
+            source_arn=source_arn, description=description, tags=tags
+        )
 
         jsii.create(CfnDiscoverer, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnDiscoverer":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnDiscoverer":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -52,7 +82,9 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -66,7 +98,9 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -139,8 +173,12 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
     def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_eventschemas.CfnDiscoverer.TagsEntryProperty", jsii_struct_bases=[], name_mapping={'key': 'key', 'value': 'value'})
-    class TagsEntryProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_eventschemas.CfnDiscoverer.TagsEntryProperty",
+        jsii_struct_bases=[],
+        name_mapping={"key": "key", "value": "value"},
+    )
+    class TagsEntryProperty:
         def __init__(self, *, key: str, value: str) -> None:
             """
             :param key: ``CfnDiscoverer.TagsEntryProperty.Key``.
@@ -150,8 +188,8 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html
             """
             self._values = {
-                'key': key,
-                'value': value,
+                "key": key,
+                "value": value,
             }
 
         @builtins.property
@@ -161,7 +199,7 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html#cfn-eventschemas-discoverer-tagsentry-key
             """
-            return self._values.get('key')
+            return self._values.get("key")
 
         @builtins.property
         def value(self) -> str:
@@ -170,7 +208,7 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-discoverer-tagsentry.html#cfn-eventschemas-discoverer-tagsentry-value
             """
-            return self._values.get('value')
+            return self._values.get("value")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -179,13 +217,28 @@ class CfnDiscoverer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="m
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'TagsEntryProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "TagsEntryProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_eventschemas.CfnDiscovererProps", jsii_struct_bases=[], name_mapping={'source_arn': 'sourceArn', 'description': 'description', 'tags': 'tags'})
-class CfnDiscovererProps():
-    def __init__(self, *, source_arn: str, description: typing.Optional[str]=None, tags: typing.Optional[typing.List["CfnDiscoverer.TagsEntryProperty"]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_eventschemas.CfnDiscovererProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "source_arn": "sourceArn",
+        "description": "description",
+        "tags": "tags",
+    },
+)
+class CfnDiscovererProps:
+    def __init__(
+        self,
+        *,
+        source_arn: str,
+        description: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List["CfnDiscoverer.TagsEntryProperty"]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Discoverer``.
 
         :param source_arn: ``AWS::EventSchemas::Discoverer.SourceArn``.
@@ -196,10 +249,12 @@ class CfnDiscovererProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html
         """
         self._values = {
-            'source_arn': source_arn,
+            "source_arn": source_arn,
         }
-        if description is not None: self._values["description"] = description
-        if tags is not None: self._values["tags"] = tags
+        if description is not None:
+            self._values["description"] = description
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def source_arn(self) -> str:
@@ -208,7 +263,7 @@ class CfnDiscovererProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-sourcearn
         """
-        return self._values.get('source_arn')
+        return self._values.get("source_arn")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -217,7 +272,7 @@ class CfnDiscovererProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["CfnDiscoverer.TagsEntryProperty"]]:
@@ -226,7 +281,7 @@ class CfnDiscovererProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-discoverer.html#cfn-eventschemas-discoverer-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -235,11 +290,17 @@ class CfnDiscovererProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnDiscovererProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnDiscovererProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistry"):
+class CfnRegistry(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistry",
+):
     """A CloudFormation ``AWS::EventSchemas::Registry``.
 
     see
@@ -247,7 +308,16 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
     cloudformationResource:
     :cloudformationResource:: AWS::EventSchemas::Registry
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, description: typing.Optional[str]=None, registry_name: typing.Optional[str]=None, tags: typing.Optional[typing.List["TagsEntryProperty"]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        description: typing.Optional[str] = None,
+        registry_name: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
+    ) -> None:
         """Create a new ``AWS::EventSchemas::Registry``.
 
         :param scope: - scope in which this resource is defined.
@@ -256,13 +326,22 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         :param registry_name: ``AWS::EventSchemas::Registry.RegistryName``.
         :param tags: ``AWS::EventSchemas::Registry.Tags``.
         """
-        props = CfnRegistryProps(description=description, registry_name=registry_name, tags=tags)
+        props = CfnRegistryProps(
+            description=description, registry_name=registry_name, tags=tags
+        )
 
         jsii.create(CfnRegistry, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnRegistry":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnRegistry":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -277,7 +356,9 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -291,7 +372,9 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -364,8 +447,12 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
     def registry_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "registryName", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistry.TagsEntryProperty", jsii_struct_bases=[], name_mapping={'key': 'key', 'value': 'value'})
-    class TagsEntryProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistry.TagsEntryProperty",
+        jsii_struct_bases=[],
+        name_mapping={"key": "key", "value": "value"},
+    )
+    class TagsEntryProperty:
         def __init__(self, *, key: str, value: str) -> None:
             """
             :param key: ``CfnRegistry.TagsEntryProperty.Key``.
@@ -375,8 +462,8 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html
             """
             self._values = {
-                'key': key,
-                'value': value,
+                "key": key,
+                "value": value,
             }
 
         @builtins.property
@@ -386,7 +473,7 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html#cfn-eventschemas-registry-tagsentry-key
             """
-            return self._values.get('key')
+            return self._values.get("key")
 
         @builtins.property
         def value(self) -> str:
@@ -395,7 +482,7 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-registry-tagsentry.html#cfn-eventschemas-registry-tagsentry-value
             """
-            return self._values.get('value')
+            return self._values.get("value")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -404,12 +491,17 @@ class CfnRegistry(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mon
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'TagsEntryProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
-
+            return "TagsEntryProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnRegistryPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistryPolicy"):
+class CfnRegistryPolicy(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistryPolicy",
+):
     """A CloudFormation ``AWS::EventSchemas::RegistryPolicy``.
 
     see
@@ -417,7 +509,16 @@ class CfnRegistryPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
     cloudformationResource:
     :cloudformationResource:: AWS::EventSchemas::RegistryPolicy
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, policy: typing.Any, registry_name: str, revision_id: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        policy: typing.Any,
+        registry_name: str,
+        revision_id: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::EventSchemas::RegistryPolicy``.
 
         :param scope: - scope in which this resource is defined.
@@ -426,13 +527,22 @@ class CfnRegistryPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         :param registry_name: ``AWS::EventSchemas::RegistryPolicy.RegistryName``.
         :param revision_id: ``AWS::EventSchemas::RegistryPolicy.RevisionId``.
         """
-        props = CfnRegistryPolicyProps(policy=policy, registry_name=registry_name, revision_id=revision_id)
+        props = CfnRegistryPolicyProps(
+            policy=policy, registry_name=registry_name, revision_id=revision_id
+        )
 
         jsii.create(CfnRegistryPolicy, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnRegistryPolicy":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnRegistryPolicy":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -447,7 +557,9 @@ class CfnRegistryPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -461,7 +573,9 @@ class CfnRegistryPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -530,9 +644,23 @@ class CfnRegistryPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         jsii.set(self, "revisionId", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistryPolicyProps", jsii_struct_bases=[], name_mapping={'policy': 'policy', 'registry_name': 'registryName', 'revision_id': 'revisionId'})
-class CfnRegistryPolicyProps():
-    def __init__(self, *, policy: typing.Any, registry_name: str, revision_id: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistryPolicyProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "policy": "policy",
+        "registry_name": "registryName",
+        "revision_id": "revisionId",
+    },
+)
+class CfnRegistryPolicyProps:
+    def __init__(
+        self,
+        *,
+        policy: typing.Any,
+        registry_name: str,
+        revision_id: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::EventSchemas::RegistryPolicy``.
 
         :param policy: ``AWS::EventSchemas::RegistryPolicy.Policy``.
@@ -543,10 +671,11 @@ class CfnRegistryPolicyProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html
         """
         self._values = {
-            'policy': policy,
-            'registry_name': registry_name,
+            "policy": policy,
+            "registry_name": registry_name,
         }
-        if revision_id is not None: self._values["revision_id"] = revision_id
+        if revision_id is not None:
+            self._values["revision_id"] = revision_id
 
     @builtins.property
     def policy(self) -> typing.Any:
@@ -555,7 +684,7 @@ class CfnRegistryPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-policy
         """
-        return self._values.get('policy')
+        return self._values.get("policy")
 
     @builtins.property
     def registry_name(self) -> str:
@@ -564,7 +693,7 @@ class CfnRegistryPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-registryname
         """
-        return self._values.get('registry_name')
+        return self._values.get("registry_name")
 
     @builtins.property
     def revision_id(self) -> typing.Optional[str]:
@@ -573,7 +702,7 @@ class CfnRegistryPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registrypolicy.html#cfn-eventschemas-registrypolicy-revisionid
         """
-        return self._values.get('revision_id')
+        return self._values.get("revision_id")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -582,12 +711,28 @@ class CfnRegistryPolicyProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnRegistryPolicyProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnRegistryPolicyProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistryProps", jsii_struct_bases=[], name_mapping={'description': 'description', 'registry_name': 'registryName', 'tags': 'tags'})
-class CfnRegistryProps():
-    def __init__(self, *, description: typing.Optional[str]=None, registry_name: typing.Optional[str]=None, tags: typing.Optional[typing.List["CfnRegistry.TagsEntryProperty"]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_eventschemas.CfnRegistryProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "description": "description",
+        "registry_name": "registryName",
+        "tags": "tags",
+    },
+)
+class CfnRegistryProps:
+    def __init__(
+        self,
+        *,
+        description: typing.Optional[str] = None,
+        registry_name: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List["CfnRegistry.TagsEntryProperty"]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Registry``.
 
         :param description: ``AWS::EventSchemas::Registry.Description``.
@@ -597,11 +742,13 @@ class CfnRegistryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html
         """
-        self._values = {
-        }
-        if description is not None: self._values["description"] = description
-        if registry_name is not None: self._values["registry_name"] = registry_name
-        if tags is not None: self._values["tags"] = tags
+        self._values = {}
+        if description is not None:
+            self._values["description"] = description
+        if registry_name is not None:
+            self._values["registry_name"] = registry_name
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -610,7 +757,7 @@ class CfnRegistryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def registry_name(self) -> typing.Optional[str]:
@@ -619,7 +766,7 @@ class CfnRegistryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-registryname
         """
-        return self._values.get('registry_name')
+        return self._values.get("registry_name")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["CfnRegistry.TagsEntryProperty"]]:
@@ -628,7 +775,7 @@ class CfnRegistryProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-registry.html#cfn-eventschemas-registry-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -637,11 +784,17 @@ class CfnRegistryProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnRegistryProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnRegistryProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_eventschemas.CfnSchema"):
+class CfnSchema(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_eventschemas.CfnSchema",
+):
     """A CloudFormation ``AWS::EventSchemas::Schema``.
 
     see
@@ -649,7 +802,19 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
     cloudformationResource:
     :cloudformationResource:: AWS::EventSchemas::Schema
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, content: str, registry_name: str, type: str, description: typing.Optional[str]=None, schema_name: typing.Optional[str]=None, tags: typing.Optional[typing.List["TagsEntryProperty"]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        content: str,
+        registry_name: str,
+        type: str,
+        description: typing.Optional[str] = None,
+        schema_name: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List["TagsEntryProperty"]] = None,
+    ) -> None:
         """Create a new ``AWS::EventSchemas::Schema``.
 
         :param scope: - scope in which this resource is defined.
@@ -661,13 +826,27 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         :param schema_name: ``AWS::EventSchemas::Schema.SchemaName``.
         :param tags: ``AWS::EventSchemas::Schema.Tags``.
         """
-        props = CfnSchemaProps(content=content, registry_name=registry_name, type=type, description=description, schema_name=schema_name, tags=tags)
+        props = CfnSchemaProps(
+            content=content,
+            registry_name=registry_name,
+            type=type,
+            description=description,
+            schema_name=schema_name,
+            tags=tags,
+        )
 
         jsii.create(CfnSchema, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnSchema":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnSchema":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -682,7 +861,9 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -696,7 +877,9 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -820,8 +1003,12 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
     def schema_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "schemaName", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_eventschemas.CfnSchema.TagsEntryProperty", jsii_struct_bases=[], name_mapping={'key': 'key', 'value': 'value'})
-    class TagsEntryProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_eventschemas.CfnSchema.TagsEntryProperty",
+        jsii_struct_bases=[],
+        name_mapping={"key": "key", "value": "value"},
+    )
+    class TagsEntryProperty:
         def __init__(self, *, key: str, value: str) -> None:
             """
             :param key: ``CfnSchema.TagsEntryProperty.Key``.
@@ -831,8 +1018,8 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html
             """
             self._values = {
-                'key': key,
-                'value': value,
+                "key": key,
+                "value": value,
             }
 
         @builtins.property
@@ -842,7 +1029,7 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html#cfn-eventschemas-schema-tagsentry-key
             """
-            return self._values.get('key')
+            return self._values.get("key")
 
         @builtins.property
         def value(self) -> str:
@@ -851,7 +1038,7 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-eventschemas-schema-tagsentry.html#cfn-eventschemas-schema-tagsentry-value
             """
-            return self._values.get('value')
+            return self._values.get("value")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -860,13 +1047,34 @@ class CfnSchema(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'TagsEntryProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "TagsEntryProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_eventschemas.CfnSchemaProps", jsii_struct_bases=[], name_mapping={'content': 'content', 'registry_name': 'registryName', 'type': 'type', 'description': 'description', 'schema_name': 'schemaName', 'tags': 'tags'})
-class CfnSchemaProps():
-    def __init__(self, *, content: str, registry_name: str, type: str, description: typing.Optional[str]=None, schema_name: typing.Optional[str]=None, tags: typing.Optional[typing.List["CfnSchema.TagsEntryProperty"]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_eventschemas.CfnSchemaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "content": "content",
+        "registry_name": "registryName",
+        "type": "type",
+        "description": "description",
+        "schema_name": "schemaName",
+        "tags": "tags",
+    },
+)
+class CfnSchemaProps:
+    def __init__(
+        self,
+        *,
+        content: str,
+        registry_name: str,
+        type: str,
+        description: typing.Optional[str] = None,
+        schema_name: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List["CfnSchema.TagsEntryProperty"]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::EventSchemas::Schema``.
 
         :param content: ``AWS::EventSchemas::Schema.Content``.
@@ -880,13 +1088,16 @@ class CfnSchemaProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html
         """
         self._values = {
-            'content': content,
-            'registry_name': registry_name,
-            'type': type,
+            "content": content,
+            "registry_name": registry_name,
+            "type": type,
         }
-        if description is not None: self._values["description"] = description
-        if schema_name is not None: self._values["schema_name"] = schema_name
-        if tags is not None: self._values["tags"] = tags
+        if description is not None:
+            self._values["description"] = description
+        if schema_name is not None:
+            self._values["schema_name"] = schema_name
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def content(self) -> str:
@@ -895,7 +1106,7 @@ class CfnSchemaProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-content
         """
-        return self._values.get('content')
+        return self._values.get("content")
 
     @builtins.property
     def registry_name(self) -> str:
@@ -904,7 +1115,7 @@ class CfnSchemaProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-registryname
         """
-        return self._values.get('registry_name')
+        return self._values.get("registry_name")
 
     @builtins.property
     def type(self) -> str:
@@ -913,7 +1124,7 @@ class CfnSchemaProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-type
         """
-        return self._values.get('type')
+        return self._values.get("type")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -922,7 +1133,7 @@ class CfnSchemaProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def schema_name(self) -> typing.Optional[str]:
@@ -931,7 +1142,7 @@ class CfnSchemaProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-schemaname
         """
-        return self._values.get('schema_name')
+        return self._values.get("schema_name")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["CfnSchema.TagsEntryProperty"]]:
@@ -940,7 +1151,7 @@ class CfnSchemaProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-eventschemas-schema.html#cfn-eventschemas-schema-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -949,7 +1160,9 @@ class CfnSchemaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnSchemaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnSchemaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
