@@ -10,11 +10,23 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IInspectable as _IInspectable_051e6ed8, IResolvable as _IResolvable_9ceae33e)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnNotificationChannel(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_fms.CfnNotificationChannel"):
+class CfnNotificationChannel(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_fms.CfnNotificationChannel",
+):
     """A CloudFormation ``AWS::FMS::NotificationChannel``.
 
     see
@@ -22,7 +34,15 @@ class CfnNotificationChannel(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsi
     cloudformationResource:
     :cloudformationResource:: AWS::FMS::NotificationChannel
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, sns_role_name: str, sns_topic_arn: str) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        sns_role_name: str,
+        sns_topic_arn: str,
+    ) -> None:
         """Create a new ``AWS::FMS::NotificationChannel``.
 
         :param scope: - scope in which this resource is defined.
@@ -30,13 +50,22 @@ class CfnNotificationChannel(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsi
         :param sns_role_name: ``AWS::FMS::NotificationChannel.SnsRoleName``.
         :param sns_topic_arn: ``AWS::FMS::NotificationChannel.SnsTopicArn``.
         """
-        props = CfnNotificationChannelProps(sns_role_name=sns_role_name, sns_topic_arn=sns_topic_arn)
+        props = CfnNotificationChannelProps(
+            sns_role_name=sns_role_name, sns_topic_arn=sns_topic_arn
+        )
 
         jsii.create(CfnNotificationChannel, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnNotificationChannel":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnNotificationChannel":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -51,7 +80,9 @@ class CfnNotificationChannel(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsi
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -65,7 +96,9 @@ class CfnNotificationChannel(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsi
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -111,8 +144,12 @@ class CfnNotificationChannel(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsi
         jsii.set(self, "snsTopicArn", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_fms.CfnNotificationChannelProps", jsii_struct_bases=[], name_mapping={'sns_role_name': 'snsRoleName', 'sns_topic_arn': 'snsTopicArn'})
-class CfnNotificationChannelProps():
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_fms.CfnNotificationChannelProps",
+    jsii_struct_bases=[],
+    name_mapping={"sns_role_name": "snsRoleName", "sns_topic_arn": "snsTopicArn"},
+)
+class CfnNotificationChannelProps:
     def __init__(self, *, sns_role_name: str, sns_topic_arn: str) -> None:
         """Properties for defining a ``AWS::FMS::NotificationChannel``.
 
@@ -123,8 +160,8 @@ class CfnNotificationChannelProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html
         """
         self._values = {
-            'sns_role_name': sns_role_name,
-            'sns_topic_arn': sns_topic_arn,
+            "sns_role_name": sns_role_name,
+            "sns_topic_arn": sns_topic_arn,
         }
 
     @builtins.property
@@ -134,7 +171,7 @@ class CfnNotificationChannelProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html#cfn-fms-notificationchannel-snsrolename
         """
-        return self._values.get('sns_role_name')
+        return self._values.get("sns_role_name")
 
     @builtins.property
     def sns_topic_arn(self) -> str:
@@ -143,7 +180,7 @@ class CfnNotificationChannelProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-notificationchannel.html#cfn-fms-notificationchannel-snstopicarn
         """
-        return self._values.get('sns_topic_arn')
+        return self._values.get("sns_topic_arn")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -152,11 +189,17 @@ class CfnNotificationChannelProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnNotificationChannelProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnNotificationChannelProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_fms.CfnPolicy"):
+class CfnPolicy(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_fms.CfnPolicy",
+):
     """A CloudFormation ``AWS::FMS::Policy``.
 
     see
@@ -164,7 +207,35 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
     cloudformationResource:
     :cloudformationResource:: AWS::FMS::Policy
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, exclude_resource_tags: typing.Union[bool, _IResolvable_9ceae33e], policy_name: str, remediation_enabled: typing.Union[bool, _IResolvable_9ceae33e], resource_type: str, security_service_policy_data: typing.Any, delete_all_policy_resources: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, exclude_map: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]=None, include_map: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]=None, resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]]=None, resource_type_list: typing.Optional[typing.List[str]]=None, tags: typing.Optional[typing.List["PolicyTagProperty"]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        exclude_resource_tags: typing.Union[bool, _IResolvable_9ceae33e],
+        policy_name: str,
+        remediation_enabled: typing.Union[bool, _IResolvable_9ceae33e],
+        resource_type: str,
+        security_service_policy_data: typing.Any,
+        delete_all_policy_resources: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        exclude_map: typing.Optional[
+            typing.Union["IEMapProperty", _IResolvable_9ceae33e]
+        ] = None,
+        include_map: typing.Optional[
+            typing.Union["IEMapProperty", _IResolvable_9ceae33e]
+        ] = None,
+        resource_tags: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]],
+            ]
+        ] = None,
+        resource_type_list: typing.Optional[typing.List[str]] = None,
+        tags: typing.Optional[typing.List["PolicyTagProperty"]] = None,
+    ) -> None:
         """Create a new ``AWS::FMS::Policy``.
 
         :param scope: - scope in which this resource is defined.
@@ -181,13 +252,32 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         :param resource_type_list: ``AWS::FMS::Policy.ResourceTypeList``.
         :param tags: ``AWS::FMS::Policy.Tags``.
         """
-        props = CfnPolicyProps(exclude_resource_tags=exclude_resource_tags, policy_name=policy_name, remediation_enabled=remediation_enabled, resource_type=resource_type, security_service_policy_data=security_service_policy_data, delete_all_policy_resources=delete_all_policy_resources, exclude_map=exclude_map, include_map=include_map, resource_tags=resource_tags, resource_type_list=resource_type_list, tags=tags)
+        props = CfnPolicyProps(
+            exclude_resource_tags=exclude_resource_tags,
+            policy_name=policy_name,
+            remediation_enabled=remediation_enabled,
+            resource_type=resource_type,
+            security_service_policy_data=security_service_policy_data,
+            delete_all_policy_resources=delete_all_policy_resources,
+            exclude_map=exclude_map,
+            include_map=include_map,
+            resource_tags=resource_tags,
+            resource_type_list=resource_type_list,
+            tags=tags,
+        )
 
         jsii.create(CfnPolicy, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnPolicy":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnPolicy":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -202,7 +292,9 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -216,7 +308,9 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -262,7 +356,9 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "excludeResourceTags")
 
     @exclude_resource_tags.setter
-    def exclude_resource_tags(self, value: typing.Union[bool, _IResolvable_9ceae33e]) -> None:
+    def exclude_resource_tags(
+        self, value: typing.Union[bool, _IResolvable_9ceae33e]
+    ) -> None:
         jsii.set(self, "excludeResourceTags", value)
 
     @builtins.property
@@ -290,7 +386,9 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "remediationEnabled")
 
     @remediation_enabled.setter
-    def remediation_enabled(self, value: typing.Union[bool, _IResolvable_9ceae33e]) -> None:
+    def remediation_enabled(
+        self, value: typing.Union[bool, _IResolvable_9ceae33e]
+    ) -> None:
         jsii.set(self, "remediationEnabled", value)
 
     @builtins.property
@@ -323,7 +421,9 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
 
     @builtins.property
     @jsii.member(jsii_name="deleteAllPolicyResources")
-    def delete_all_policy_resources(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def delete_all_policy_resources(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.DeleteAllPolicyResources``.
 
         see
@@ -332,12 +432,16 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "deleteAllPolicyResources")
 
     @delete_all_policy_resources.setter
-    def delete_all_policy_resources(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def delete_all_policy_resources(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "deleteAllPolicyResources", value)
 
     @builtins.property
     @jsii.member(jsii_name="excludeMap")
-    def exclude_map(self) -> typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]:
+    def exclude_map(
+        self,
+    ) -> typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.ExcludeMap``.
 
         see
@@ -346,12 +450,17 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "excludeMap")
 
     @exclude_map.setter
-    def exclude_map(self, value: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]) -> None:
+    def exclude_map(
+        self,
+        value: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]],
+    ) -> None:
         jsii.set(self, "excludeMap", value)
 
     @builtins.property
     @jsii.member(jsii_name="includeMap")
-    def include_map(self) -> typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]:
+    def include_map(
+        self,
+    ) -> typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.IncludeMap``.
 
         see
@@ -360,12 +469,22 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "includeMap")
 
     @include_map.setter
-    def include_map(self, value: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]]) -> None:
+    def include_map(
+        self,
+        value: typing.Optional[typing.Union["IEMapProperty", _IResolvable_9ceae33e]],
+    ) -> None:
         jsii.set(self, "includeMap", value)
 
     @builtins.property
     @jsii.member(jsii_name="resourceTags")
-    def resource_tags(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]]:
+    def resource_tags(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]],
+        ]
+    ]:
         """``AWS::FMS::Policy.ResourceTags``.
 
         see
@@ -374,7 +493,15 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "resourceTags")
 
     @resource_tags.setter
-    def resource_tags(self, value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]]]]) -> None:
+    def resource_tags(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["ResourceTagProperty", _IResolvable_9ceae33e]],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "resourceTags", value)
 
     @builtins.property
@@ -411,6 +538,7 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html
         """
+
         @builtins.staticmethod
         def __jsii_proxy_class__():
             return _IEMapPropertyProxy
@@ -435,13 +563,14 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             """
             ...
 
-
-    class _IEMapPropertyProxy():
+    class _IEMapPropertyProxy:
         """
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html
         """
+
         __jsii_type__ = "monocdk-experiment.aws_fms.CfnPolicy.IEMapProperty"
+
         @builtins.property
         @jsii.member(jsii_name="account")
         def account(self) -> typing.Optional[typing.List[str]]:
@@ -462,9 +591,12 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             """
             return jsii.get(self, "orgunit")
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_fms.CfnPolicy.PolicyTagProperty", jsii_struct_bases=[], name_mapping={'key': 'key', 'value': 'value'})
-    class PolicyTagProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_fms.CfnPolicy.PolicyTagProperty",
+        jsii_struct_bases=[],
+        name_mapping={"key": "key", "value": "value"},
+    )
+    class PolicyTagProperty:
         def __init__(self, *, key: str, value: str) -> None:
             """
             :param key: ``CfnPolicy.PolicyTagProperty.Key``.
@@ -474,8 +606,8 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html
             """
             self._values = {
-                'key': key,
-                'value': value,
+                "key": key,
+                "value": value,
             }
 
         @builtins.property
@@ -485,7 +617,7 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html#cfn-fms-policy-policytag-key
             """
-            return self._values.get('key')
+            return self._values.get("key")
 
         @builtins.property
         def value(self) -> str:
@@ -494,7 +626,7 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-policytag.html#cfn-fms-policy-policytag-value
             """
-            return self._values.get('value')
+            return self._values.get("value")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -503,12 +635,17 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'PolicyTagProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "PolicyTagProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_fms.CfnPolicy.ResourceTagProperty", jsii_struct_bases=[], name_mapping={'key': 'key', 'value': 'value'})
-    class ResourceTagProperty():
-        def __init__(self, *, key: str, value: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_fms.CfnPolicy.ResourceTagProperty",
+        jsii_struct_bases=[],
+        name_mapping={"key": "key", "value": "value"},
+    )
+    class ResourceTagProperty:
+        def __init__(self, *, key: str, value: typing.Optional[str] = None) -> None:
             """
             :param key: ``CfnPolicy.ResourceTagProperty.Key``.
             :param value: ``CfnPolicy.ResourceTagProperty.Value``.
@@ -517,9 +654,10 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html
             """
             self._values = {
-                'key': key,
+                "key": key,
             }
-            if value is not None: self._values["value"] = value
+            if value is not None:
+                self._values["value"] = value
 
         @builtins.property
         def key(self) -> str:
@@ -528,7 +666,7 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html#cfn-fms-policy-resourcetag-key
             """
-            return self._values.get('key')
+            return self._values.get("key")
 
         @builtins.property
         def value(self) -> typing.Optional[str]:
@@ -537,7 +675,7 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-resourcetag.html#cfn-fms-policy-resourcetag-value
             """
-            return self._values.get('value')
+            return self._values.get("value")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -546,13 +684,57 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'ResourceTagProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "ResourceTagProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_fms.CfnPolicyProps", jsii_struct_bases=[], name_mapping={'exclude_resource_tags': 'excludeResourceTags', 'policy_name': 'policyName', 'remediation_enabled': 'remediationEnabled', 'resource_type': 'resourceType', 'security_service_policy_data': 'securityServicePolicyData', 'delete_all_policy_resources': 'deleteAllPolicyResources', 'exclude_map': 'excludeMap', 'include_map': 'includeMap', 'resource_tags': 'resourceTags', 'resource_type_list': 'resourceTypeList', 'tags': 'tags'})
-class CfnPolicyProps():
-    def __init__(self, *, exclude_resource_tags: typing.Union[bool, _IResolvable_9ceae33e], policy_name: str, remediation_enabled: typing.Union[bool, _IResolvable_9ceae33e], resource_type: str, security_service_policy_data: typing.Any, delete_all_policy_resources: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, exclude_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]=None, include_map: typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]=None, resource_tags: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]]=None, resource_type_list: typing.Optional[typing.List[str]]=None, tags: typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_fms.CfnPolicyProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "exclude_resource_tags": "excludeResourceTags",
+        "policy_name": "policyName",
+        "remediation_enabled": "remediationEnabled",
+        "resource_type": "resourceType",
+        "security_service_policy_data": "securityServicePolicyData",
+        "delete_all_policy_resources": "deleteAllPolicyResources",
+        "exclude_map": "excludeMap",
+        "include_map": "includeMap",
+        "resource_tags": "resourceTags",
+        "resource_type_list": "resourceTypeList",
+        "tags": "tags",
+    },
+)
+class CfnPolicyProps:
+    def __init__(
+        self,
+        *,
+        exclude_resource_tags: typing.Union[bool, _IResolvable_9ceae33e],
+        policy_name: str,
+        remediation_enabled: typing.Union[bool, _IResolvable_9ceae33e],
+        resource_type: str,
+        security_service_policy_data: typing.Any,
+        delete_all_policy_resources: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        exclude_map: typing.Optional[
+            typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]
+        ] = None,
+        include_map: typing.Optional[
+            typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]
+        ] = None,
+        resource_tags: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]
+                ],
+            ]
+        ] = None,
+        resource_type_list: typing.Optional[typing.List[str]] = None,
+        tags: typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::FMS::Policy``.
 
         :param exclude_resource_tags: ``AWS::FMS::Policy.ExcludeResourceTags``.
@@ -571,18 +753,24 @@ class CfnPolicyProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html
         """
         self._values = {
-            'exclude_resource_tags': exclude_resource_tags,
-            'policy_name': policy_name,
-            'remediation_enabled': remediation_enabled,
-            'resource_type': resource_type,
-            'security_service_policy_data': security_service_policy_data,
+            "exclude_resource_tags": exclude_resource_tags,
+            "policy_name": policy_name,
+            "remediation_enabled": remediation_enabled,
+            "resource_type": resource_type,
+            "security_service_policy_data": security_service_policy_data,
         }
-        if delete_all_policy_resources is not None: self._values["delete_all_policy_resources"] = delete_all_policy_resources
-        if exclude_map is not None: self._values["exclude_map"] = exclude_map
-        if include_map is not None: self._values["include_map"] = include_map
-        if resource_tags is not None: self._values["resource_tags"] = resource_tags
-        if resource_type_list is not None: self._values["resource_type_list"] = resource_type_list
-        if tags is not None: self._values["tags"] = tags
+        if delete_all_policy_resources is not None:
+            self._values["delete_all_policy_resources"] = delete_all_policy_resources
+        if exclude_map is not None:
+            self._values["exclude_map"] = exclude_map
+        if include_map is not None:
+            self._values["include_map"] = include_map
+        if resource_tags is not None:
+            self._values["resource_tags"] = resource_tags
+        if resource_type_list is not None:
+            self._values["resource_type_list"] = resource_type_list
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def exclude_resource_tags(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
@@ -591,7 +779,7 @@ class CfnPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-excluderesourcetags
         """
-        return self._values.get('exclude_resource_tags')
+        return self._values.get("exclude_resource_tags")
 
     @builtins.property
     def policy_name(self) -> str:
@@ -600,7 +788,7 @@ class CfnPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-policyname
         """
-        return self._values.get('policy_name')
+        return self._values.get("policy_name")
 
     @builtins.property
     def remediation_enabled(self) -> typing.Union[bool, _IResolvable_9ceae33e]:
@@ -609,7 +797,7 @@ class CfnPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-remediationenabled
         """
-        return self._values.get('remediation_enabled')
+        return self._values.get("remediation_enabled")
 
     @builtins.property
     def resource_type(self) -> str:
@@ -618,7 +806,7 @@ class CfnPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetype
         """
-        return self._values.get('resource_type')
+        return self._values.get("resource_type")
 
     @builtins.property
     def security_service_policy_data(self) -> typing.Any:
@@ -627,43 +815,62 @@ class CfnPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-securityservicepolicydata
         """
-        return self._values.get('security_service_policy_data')
+        return self._values.get("security_service_policy_data")
 
     @builtins.property
-    def delete_all_policy_resources(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def delete_all_policy_resources(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::FMS::Policy.DeleteAllPolicyResources``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-deleteallpolicyresources
         """
-        return self._values.get('delete_all_policy_resources')
+        return self._values.get("delete_all_policy_resources")
 
     @builtins.property
-    def exclude_map(self) -> typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]:
+    def exclude_map(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::FMS::Policy.ExcludeMap``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-excludemap
         """
-        return self._values.get('exclude_map')
+        return self._values.get("exclude_map")
 
     @builtins.property
-    def include_map(self) -> typing.Optional[typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]]:
+    def include_map(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnPolicy.IEMapProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::FMS::Policy.IncludeMap``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-includemap
         """
-        return self._values.get('include_map')
+        return self._values.get("include_map")
 
     @builtins.property
-    def resource_tags(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]]]]:
+    def resource_tags(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union["CfnPolicy.ResourceTagProperty", _IResolvable_9ceae33e]
+            ],
+        ]
+    ]:
         """``AWS::FMS::Policy.ResourceTags``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetags
         """
-        return self._values.get('resource_tags')
+        return self._values.get("resource_tags")
 
     @builtins.property
     def resource_type_list(self) -> typing.Optional[typing.List[str]]:
@@ -672,7 +879,7 @@ class CfnPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-resourcetypelist
         """
-        return self._values.get('resource_type_list')
+        return self._values.get("resource_type_list")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List["CfnPolicy.PolicyTagProperty"]]:
@@ -681,7 +888,7 @@ class CfnPolicyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fms-policy.html#cfn-fms-policy-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -690,7 +897,9 @@ class CfnPolicyProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnPolicyProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnPolicyProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
