@@ -10,13 +10,30 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, CfnTag as _CfnTag_b4661f1a, IResource as _IResource_72f7ee7e, Resource as _Resource_884d0774, Duration as _Duration_5170c158)
-from ..aws_iam import (Grant as _Grant_96af6d2d, IGrantable as _IGrantable_0fcfc53a)
-from ..aws_kms import (IKey as _IKey_3336c79d)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+    IResource as _IResource_72f7ee7e,
+    Resource as _Resource_884d0774,
+    Duration as _Duration_5170c158,
+)
+from ..aws_iam import Grant as _Grant_96af6d2d, IGrantable as _IGrantable_0fcfc53a
+from ..aws_kms import IKey as _IKey_3336c79d
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_kinesis.CfnStream"):
+class CfnStream(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_kinesis.CfnStream",
+):
     """A CloudFormation ``AWS::Kinesis::Stream``.
 
     see
@@ -24,7 +41,20 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
     cloudformationResource:
     :cloudformationResource:: AWS::Kinesis::Stream
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, shard_count: jsii.Number, name: typing.Optional[str]=None, retention_period_hours: typing.Optional[jsii.Number]=None, stream_encryption: typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        shard_count: jsii.Number,
+        name: typing.Optional[str] = None,
+        retention_period_hours: typing.Optional[jsii.Number] = None,
+        stream_encryption: typing.Optional[
+            typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]
+        ] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Create a new ``AWS::Kinesis::Stream``.
 
         :param scope: - scope in which this resource is defined.
@@ -35,13 +65,26 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         :param stream_encryption: ``AWS::Kinesis::Stream.StreamEncryption``.
         :param tags: ``AWS::Kinesis::Stream.Tags``.
         """
-        props = CfnStreamProps(shard_count=shard_count, name=name, retention_period_hours=retention_period_hours, stream_encryption=stream_encryption, tags=tags)
+        props = CfnStreamProps(
+            shard_count=shard_count,
+            name=name,
+            retention_period_hours=retention_period_hours,
+            stream_encryption=stream_encryption,
+            tags=tags,
+        )
 
         jsii.create(CfnStream, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnStream":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnStream":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -56,7 +99,9 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -70,7 +115,9 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -150,7 +197,11 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
 
     @builtins.property
     @jsii.member(jsii_name="streamEncryption")
-    def stream_encryption(self) -> typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]]:
+    def stream_encryption(
+        self,
+    ) -> typing.Optional[
+        typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::Kinesis::Stream.StreamEncryption``.
 
         see
@@ -159,11 +210,20 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.get(self, "streamEncryption")
 
     @stream_encryption.setter
-    def stream_encryption(self, value: typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]]) -> None:
+    def stream_encryption(
+        self,
+        value: typing.Optional[
+            typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
         jsii.set(self, "streamEncryption", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_kinesis.CfnStream.StreamEncryptionProperty", jsii_struct_bases=[], name_mapping={'encryption_type': 'encryptionType', 'key_id': 'keyId'})
-    class StreamEncryptionProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_kinesis.CfnStream.StreamEncryptionProperty",
+        jsii_struct_bases=[],
+        name_mapping={"encryption_type": "encryptionType", "key_id": "keyId"},
+    )
+    class StreamEncryptionProperty:
         def __init__(self, *, encryption_type: str, key_id: str) -> None:
             """
             :param encryption_type: ``CfnStream.StreamEncryptionProperty.EncryptionType``.
@@ -173,8 +233,8 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html
             """
             self._values = {
-                'encryption_type': encryption_type,
-                'key_id': key_id,
+                "encryption_type": encryption_type,
+                "key_id": key_id,
             }
 
         @builtins.property
@@ -184,7 +244,7 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html#cfn-kinesis-stream-streamencryption-encryptiontype
             """
-            return self._values.get('encryption_type')
+            return self._values.get("encryption_type")
 
         @builtins.property
         def key_id(self) -> str:
@@ -193,7 +253,7 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kinesis-stream-streamencryption.html#cfn-kinesis-stream-streamencryption-keyid
             """
-            return self._values.get('key_id')
+            return self._values.get("key_id")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -202,12 +262,17 @@ class CfnStream(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'StreamEncryptionProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
-
+            return "StreamEncryptionProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnStreamConsumer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_kinesis.CfnStreamConsumer"):
+class CfnStreamConsumer(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_kinesis.CfnStreamConsumer",
+):
     """A CloudFormation ``AWS::Kinesis::StreamConsumer``.
 
     see
@@ -215,7 +280,15 @@ class CfnStreamConsumer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
     cloudformationResource:
     :cloudformationResource:: AWS::Kinesis::StreamConsumer
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, consumer_name: str, stream_arn: str) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        consumer_name: str,
+        stream_arn: str,
+    ) -> None:
         """Create a new ``AWS::Kinesis::StreamConsumer``.
 
         :param scope: - scope in which this resource is defined.
@@ -223,13 +296,22 @@ class CfnStreamConsumer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         :param consumer_name: ``AWS::Kinesis::StreamConsumer.ConsumerName``.
         :param stream_arn: ``AWS::Kinesis::StreamConsumer.StreamARN``.
         """
-        props = CfnStreamConsumerProps(consumer_name=consumer_name, stream_arn=stream_arn)
+        props = CfnStreamConsumerProps(
+            consumer_name=consumer_name, stream_arn=stream_arn
+        )
 
         jsii.create(CfnStreamConsumer, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnStreamConsumer":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnStreamConsumer":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -244,7 +326,9 @@ class CfnStreamConsumer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -258,7 +342,9 @@ class CfnStreamConsumer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -349,8 +435,12 @@ class CfnStreamConsumer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_typ
         jsii.set(self, "streamArn", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kinesis.CfnStreamConsumerProps", jsii_struct_bases=[], name_mapping={'consumer_name': 'consumerName', 'stream_arn': 'streamArn'})
-class CfnStreamConsumerProps():
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kinesis.CfnStreamConsumerProps",
+    jsii_struct_bases=[],
+    name_mapping={"consumer_name": "consumerName", "stream_arn": "streamArn"},
+)
+class CfnStreamConsumerProps:
     def __init__(self, *, consumer_name: str, stream_arn: str) -> None:
         """Properties for defining a ``AWS::Kinesis::StreamConsumer``.
 
@@ -361,8 +451,8 @@ class CfnStreamConsumerProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html
         """
         self._values = {
-            'consumer_name': consumer_name,
-            'stream_arn': stream_arn,
+            "consumer_name": consumer_name,
+            "stream_arn": stream_arn,
         }
 
     @builtins.property
@@ -372,7 +462,7 @@ class CfnStreamConsumerProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html#cfn-kinesis-streamconsumer-consumername
         """
-        return self._values.get('consumer_name')
+        return self._values.get("consumer_name")
 
     @builtins.property
     def stream_arn(self) -> str:
@@ -381,7 +471,7 @@ class CfnStreamConsumerProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html#cfn-kinesis-streamconsumer-streamarn
         """
-        return self._values.get('stream_arn')
+        return self._values.get("stream_arn")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -390,12 +480,34 @@ class CfnStreamConsumerProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnStreamConsumerProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnStreamConsumerProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kinesis.CfnStreamProps", jsii_struct_bases=[], name_mapping={'shard_count': 'shardCount', 'name': 'name', 'retention_period_hours': 'retentionPeriodHours', 'stream_encryption': 'streamEncryption', 'tags': 'tags'})
-class CfnStreamProps():
-    def __init__(self, *, shard_count: jsii.Number, name: typing.Optional[str]=None, retention_period_hours: typing.Optional[jsii.Number]=None, stream_encryption: typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kinesis.CfnStreamProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "shard_count": "shardCount",
+        "name": "name",
+        "retention_period_hours": "retentionPeriodHours",
+        "stream_encryption": "streamEncryption",
+        "tags": "tags",
+    },
+)
+class CfnStreamProps:
+    def __init__(
+        self,
+        *,
+        shard_count: jsii.Number,
+        name: typing.Optional[str] = None,
+        retention_period_hours: typing.Optional[jsii.Number] = None,
+        stream_encryption: typing.Optional[
+            typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]
+        ] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Kinesis::Stream``.
 
         :param shard_count: ``AWS::Kinesis::Stream.ShardCount``.
@@ -408,12 +520,16 @@ class CfnStreamProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html
         """
         self._values = {
-            'shard_count': shard_count,
+            "shard_count": shard_count,
         }
-        if name is not None: self._values["name"] = name
-        if retention_period_hours is not None: self._values["retention_period_hours"] = retention_period_hours
-        if stream_encryption is not None: self._values["stream_encryption"] = stream_encryption
-        if tags is not None: self._values["tags"] = tags
+        if name is not None:
+            self._values["name"] = name
+        if retention_period_hours is not None:
+            self._values["retention_period_hours"] = retention_period_hours
+        if stream_encryption is not None:
+            self._values["stream_encryption"] = stream_encryption
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def shard_count(self) -> jsii.Number:
@@ -422,7 +538,7 @@ class CfnStreamProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-shardcount
         """
-        return self._values.get('shard_count')
+        return self._values.get("shard_count")
 
     @builtins.property
     def name(self) -> typing.Optional[str]:
@@ -431,7 +547,7 @@ class CfnStreamProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def retention_period_hours(self) -> typing.Optional[jsii.Number]:
@@ -440,16 +556,20 @@ class CfnStreamProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-retentionperiodhours
         """
-        return self._values.get('retention_period_hours')
+        return self._values.get("retention_period_hours")
 
     @builtins.property
-    def stream_encryption(self) -> typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]]:
+    def stream_encryption(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::Kinesis::Stream.StreamEncryption``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-streamencryption
         """
-        return self._values.get('stream_encryption')
+        return self._values.get("stream_encryption")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -458,7 +578,7 @@ class CfnStreamProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-stream.html#cfn-kinesis-stream-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -467,7 +587,9 @@ class CfnStreamProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnStreamProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnStreamProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_kinesis.IStream")
@@ -477,6 +599,7 @@ class IStream(_IResource_72f7ee7e, jsii.compat.Protocol):
     stability
     :stability: experimental
     """
+
     @builtins.staticmethod
     def __jsii_proxy_class__():
         return _IStreamProxy
@@ -576,7 +699,9 @@ class _IStreamProxy(jsii.proxy_for(_IResource_72f7ee7e)):
     stability
     :stability: experimental
     """
+
     __jsii_type__ = "monocdk-experiment.aws_kinesis.IStream"
+
     @builtins.property
     @jsii.member(jsii_name="streamArn")
     def stream_arn(self) -> str:
@@ -667,7 +792,11 @@ class _IStreamProxy(jsii.proxy_for(_IResource_72f7ee7e)):
 
 
 @jsii.implements(IStream)
-class Stream(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_kinesis.Stream"):
+class Stream(
+    _Resource_884d0774,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_kinesis.Stream",
+):
     """A Kinesis stream.
 
     Can be encrypted with a KMS key.
@@ -675,7 +804,18 @@ class Stream(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-exp
     stability
     :stability: experimental
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, encryption: typing.Optional["StreamEncryption"]=None, encryption_key: typing.Optional[_IKey_3336c79d]=None, retention_period: typing.Optional[_Duration_5170c158]=None, shard_count: typing.Optional[jsii.Number]=None, stream_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        encryption: typing.Optional["StreamEncryption"] = None,
+        encryption_key: typing.Optional[_IKey_3336c79d] = None,
+        retention_period: typing.Optional[_Duration_5170c158] = None,
+        shard_count: typing.Optional[jsii.Number] = None,
+        stream_name: typing.Optional[str] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -688,13 +828,21 @@ class Stream(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-exp
         stability
         :stability: experimental
         """
-        props = StreamProps(encryption=encryption, encryption_key=encryption_key, retention_period=retention_period, shard_count=shard_count, stream_name=stream_name)
+        props = StreamProps(
+            encryption=encryption,
+            encryption_key=encryption_key,
+            retention_period=retention_period,
+            shard_count=shard_count,
+            stream_name=stream_name,
+        )
 
         jsii.create(Stream, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromStreamArn")
     @builtins.classmethod
-    def from_stream_arn(cls, scope: _Construct_f50a3f53, id: str, stream_arn: str) -> "IStream":
+    def from_stream_arn(
+        cls, scope: _Construct_f50a3f53, id: str, stream_arn: str
+    ) -> "IStream":
         """Import an existing Kinesis Stream provided an ARN.
 
         :param scope: The parent creating construct (usually ``this``).
@@ -708,7 +856,14 @@ class Stream(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-exp
 
     @jsii.member(jsii_name="fromStreamAttributes")
     @builtins.classmethod
-    def from_stream_attributes(cls, scope: _Construct_f50a3f53, id: str, *, stream_arn: str, encryption_key: typing.Optional[_IKey_3336c79d]=None) -> "IStream":
+    def from_stream_attributes(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        stream_arn: str,
+        encryption_key: typing.Optional[_IKey_3336c79d] = None,
+    ) -> "IStream":
         """Creates a Stream construct that represents an external stream.
 
         :param scope: The parent creating construct (usually ``this``).
@@ -808,9 +963,15 @@ class Stream(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-exp
         return jsii.get(self, "encryptionKey")
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kinesis.StreamAttributes", jsii_struct_bases=[], name_mapping={'stream_arn': 'streamArn', 'encryption_key': 'encryptionKey'})
-class StreamAttributes():
-    def __init__(self, *, stream_arn: str, encryption_key: typing.Optional[_IKey_3336c79d]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kinesis.StreamAttributes",
+    jsii_struct_bases=[],
+    name_mapping={"stream_arn": "streamArn", "encryption_key": "encryptionKey"},
+)
+class StreamAttributes:
+    def __init__(
+        self, *, stream_arn: str, encryption_key: typing.Optional[_IKey_3336c79d] = None
+    ) -> None:
         """A reference to a stream.
 
         The easiest way to instantiate is to call
@@ -824,9 +985,10 @@ class StreamAttributes():
         :stability: experimental
         """
         self._values = {
-            'stream_arn': stream_arn,
+            "stream_arn": stream_arn,
         }
-        if encryption_key is not None: self._values["encryption_key"] = encryption_key
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
 
     @builtins.property
     def stream_arn(self) -> str:
@@ -835,7 +997,7 @@ class StreamAttributes():
         stability
         :stability: experimental
         """
-        return self._values.get('stream_arn')
+        return self._values.get("stream_arn")
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
@@ -847,7 +1009,7 @@ class StreamAttributes():
         stability
         :stability: experimental
         """
-        return self._values.get('encryption_key')
+        return self._values.get("encryption_key")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -856,7 +1018,9 @@ class StreamAttributes():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'StreamAttributes(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "StreamAttributes(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.enum(jsii_type="monocdk-experiment.aws_kinesis.StreamEncryption")
@@ -866,6 +1030,7 @@ class StreamEncryption(enum.Enum):
     stability
     :stability: experimental
     """
+
     UNENCRYPTED = "UNENCRYPTED"
     """Records in the stream are not encrypted.
 
@@ -887,9 +1052,28 @@ class StreamEncryption(enum.Enum):
     :stability: experimental
     """
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kinesis.StreamProps", jsii_struct_bases=[], name_mapping={'encryption': 'encryption', 'encryption_key': 'encryptionKey', 'retention_period': 'retentionPeriod', 'shard_count': 'shardCount', 'stream_name': 'streamName'})
-class StreamProps():
-    def __init__(self, *, encryption: typing.Optional["StreamEncryption"]=None, encryption_key: typing.Optional[_IKey_3336c79d]=None, retention_period: typing.Optional[_Duration_5170c158]=None, shard_count: typing.Optional[jsii.Number]=None, stream_name: typing.Optional[str]=None) -> None:
+
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kinesis.StreamProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "encryption": "encryption",
+        "encryption_key": "encryptionKey",
+        "retention_period": "retentionPeriod",
+        "shard_count": "shardCount",
+        "stream_name": "streamName",
+    },
+)
+class StreamProps:
+    def __init__(
+        self,
+        *,
+        encryption: typing.Optional["StreamEncryption"] = None,
+        encryption_key: typing.Optional[_IKey_3336c79d] = None,
+        retention_period: typing.Optional[_Duration_5170c158] = None,
+        shard_count: typing.Optional[jsii.Number] = None,
+        stream_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for a Kinesis Stream.
 
         :param encryption: The kind of server-side encryption to apply to this stream. If you choose KMS, you can specify a KMS key via ``encryptionKey``. If encryption key is not specified, a key will automatically be created. Default: - StreamEncryption.KMS if encrypted Streams are supported in the region or StreamEncryption.UNENCRYPTED otherwise. StreamEncryption.KMS if an encryption key is supplied through the encryptionKey property
@@ -901,13 +1085,17 @@ class StreamProps():
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if encryption is not None: self._values["encryption"] = encryption
-        if encryption_key is not None: self._values["encryption_key"] = encryption_key
-        if retention_period is not None: self._values["retention_period"] = retention_period
-        if shard_count is not None: self._values["shard_count"] = shard_count
-        if stream_name is not None: self._values["stream_name"] = stream_name
+        self._values = {}
+        if encryption is not None:
+            self._values["encryption"] = encryption
+        if encryption_key is not None:
+            self._values["encryption_key"] = encryption_key
+        if retention_period is not None:
+            self._values["retention_period"] = retention_period
+        if shard_count is not None:
+            self._values["shard_count"] = shard_count
+        if stream_name is not None:
+            self._values["stream_name"] = stream_name
 
     @builtins.property
     def encryption(self) -> typing.Optional["StreamEncryption"]:
@@ -926,7 +1114,7 @@ class StreamProps():
         stability
         :stability: experimental
         """
-        return self._values.get('encryption')
+        return self._values.get("encryption")
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[_IKey_3336c79d]:
@@ -944,7 +1132,7 @@ class StreamProps():
         stability
         :stability: experimental
         """
-        return self._values.get('encryption_key')
+        return self._values.get("encryption_key")
 
     @builtins.property
     def retention_period(self) -> typing.Optional[_Duration_5170c158]:
@@ -956,7 +1144,7 @@ class StreamProps():
         stability
         :stability: experimental
         """
-        return self._values.get('retention_period')
+        return self._values.get("retention_period")
 
     @builtins.property
     def shard_count(self) -> typing.Optional[jsii.Number]:
@@ -968,7 +1156,7 @@ class StreamProps():
         stability
         :stability: experimental
         """
-        return self._values.get('shard_count')
+        return self._values.get("shard_count")
 
     @builtins.property
     def stream_name(self) -> typing.Optional[str]:
@@ -980,7 +1168,7 @@ class StreamProps():
         stability
         :stability: experimental
         """
-        return self._values.get('stream_name')
+        return self._values.get("stream_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -989,7 +1177,9 @@ class StreamProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'StreamProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "StreamProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
