@@ -10,12 +10,38 @@ import publication
 
 from .._jsii import *
 
-from .. import (Resource as _Resource_884d0774, Construct as _Construct_f50a3f53, RemovalPolicy as _RemovalPolicy_5986e9f3, CfnResource as _CfnResource_7760e8e4, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IInspectable as _IInspectable_051e6ed8, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, CfnTag as _CfnTag_b4661f1a, IResource as _IResource_72f7ee7e)
-from ..aws_iam import (AddToResourcePolicyResult as _AddToResourcePolicyResult_d2a345d1, PolicyStatement as _PolicyStatement_f75dc775, Grant as _Grant_96af6d2d, IGrantable as _IGrantable_0fcfc53a, PolicyDocument as _PolicyDocument_1d1bca11, PrincipalBase as _PrincipalBase_e4459eeb, IPrincipal as _IPrincipal_97126874, PrincipalPolicyFragment as _PrincipalPolicyFragment_621f702c)
+from .. import (
+    Resource as _Resource_884d0774,
+    Construct as _Construct_f50a3f53,
+    RemovalPolicy as _RemovalPolicy_5986e9f3,
+    CfnResource as _CfnResource_7760e8e4,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+    TagManager as _TagManager_2508893f,
+    IResource as _IResource_72f7ee7e,
+)
+from ..aws_iam import (
+    AddToResourcePolicyResult as _AddToResourcePolicyResult_d2a345d1,
+    PolicyStatement as _PolicyStatement_f75dc775,
+    Grant as _Grant_96af6d2d,
+    IGrantable as _IGrantable_0fcfc53a,
+    PolicyDocument as _PolicyDocument_1d1bca11,
+    PrincipalBase as _PrincipalBase_e4459eeb,
+    IPrincipal as _IPrincipal_97126874,
+    PrincipalPolicyFragment as _PrincipalPolicyFragment_621f702c,
+)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kms.AliasAttributes", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'alias_target_key': 'aliasTargetKey'})
-class AliasAttributes():
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kms.AliasAttributes",
+    jsii_struct_bases=[],
+    name_mapping={"alias_name": "aliasName", "alias_target_key": "aliasTargetKey"},
+)
+class AliasAttributes:
     def __init__(self, *, alias_name: str, alias_target_key: "IKey") -> None:
         """Properties of a reference to an existing KMS Alias.
 
@@ -26,8 +52,8 @@ class AliasAttributes():
         :stability: experimental
         """
         self._values = {
-            'alias_name': alias_name,
-            'alias_target_key': alias_target_key,
+            "alias_name": alias_name,
+            "alias_target_key": alias_target_key,
         }
 
     @builtins.property
@@ -39,7 +65,7 @@ class AliasAttributes():
         stability
         :stability: experimental
         """
-        return self._values.get('alias_name')
+        return self._values.get("alias_name")
 
     @builtins.property
     def alias_target_key(self) -> "IKey":
@@ -48,7 +74,7 @@ class AliasAttributes():
         stability
         :stability: experimental
         """
-        return self._values.get('alias_target_key')
+        return self._values.get("alias_target_key")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -57,12 +83,28 @@ class AliasAttributes():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'AliasAttributes(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "AliasAttributes(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kms.AliasProps", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'target_key': 'targetKey', 'removal_policy': 'removalPolicy'})
-class AliasProps():
-    def __init__(self, *, alias_name: str, target_key: "IKey", removal_policy: typing.Optional[_RemovalPolicy_5986e9f3]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kms.AliasProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "alias_name": "aliasName",
+        "target_key": "targetKey",
+        "removal_policy": "removalPolicy",
+    },
+)
+class AliasProps:
+    def __init__(
+        self,
+        *,
+        alias_name: str,
+        target_key: "IKey",
+        removal_policy: typing.Optional[_RemovalPolicy_5986e9f3] = None,
+    ) -> None:
         """Construction properties for a KMS Key Alias object.
 
         :param alias_name: The name of the alias. The name must start with alias followed by a forward slash, such as alias/. You can't specify aliases that begin with alias/AWS. These aliases are reserved.
@@ -73,10 +115,11 @@ class AliasProps():
         :stability: experimental
         """
         self._values = {
-            'alias_name': alias_name,
-            'target_key': target_key,
+            "alias_name": alias_name,
+            "target_key": target_key,
         }
-        if removal_policy is not None: self._values["removal_policy"] = removal_policy
+        if removal_policy is not None:
+            self._values["removal_policy"] = removal_policy
 
     @builtins.property
     def alias_name(self) -> str:
@@ -89,7 +132,7 @@ class AliasProps():
         stability
         :stability: experimental
         """
-        return self._values.get('alias_name')
+        return self._values.get("alias_name")
 
     @builtins.property
     def target_key(self) -> "IKey":
@@ -102,7 +145,7 @@ class AliasProps():
         stability
         :stability: experimental
         """
-        return self._values.get('target_key')
+        return self._values.get("target_key")
 
     @builtins.property
     def removal_policy(self) -> typing.Optional[_RemovalPolicy_5986e9f3]:
@@ -114,7 +157,7 @@ class AliasProps():
         stability
         :stability: experimental
         """
-        return self._values.get('removal_policy')
+        return self._values.get("removal_policy")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -123,11 +166,17 @@ class AliasProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'AliasProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "AliasProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnAlias(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_kms.CfnAlias"):
+class CfnAlias(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_kms.CfnAlias",
+):
     """A CloudFormation ``AWS::KMS::Alias``.
 
     see
@@ -135,7 +184,15 @@ class CfnAlias(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
     cloudformationResource:
     :cloudformationResource:: AWS::KMS::Alias
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, alias_name: str, target_key_id: str) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        alias_name: str,
+        target_key_id: str,
+    ) -> None:
         """Create a new ``AWS::KMS::Alias``.
 
         :param scope: - scope in which this resource is defined.
@@ -149,7 +206,14 @@ class CfnAlias(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnAlias":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnAlias":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -164,7 +228,9 @@ class CfnAlias(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -178,7 +244,9 @@ class CfnAlias(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -224,8 +292,12 @@ class CfnAlias(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocd
         jsii.set(self, "targetKeyId", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kms.CfnAliasProps", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'target_key_id': 'targetKeyId'})
-class CfnAliasProps():
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kms.CfnAliasProps",
+    jsii_struct_bases=[],
+    name_mapping={"alias_name": "aliasName", "target_key_id": "targetKeyId"},
+)
+class CfnAliasProps:
     def __init__(self, *, alias_name: str, target_key_id: str) -> None:
         """Properties for defining a ``AWS::KMS::Alias``.
 
@@ -236,8 +308,8 @@ class CfnAliasProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html
         """
         self._values = {
-            'alias_name': alias_name,
-            'target_key_id': target_key_id,
+            "alias_name": alias_name,
+            "target_key_id": target_key_id,
         }
 
     @builtins.property
@@ -247,7 +319,7 @@ class CfnAliasProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-aliasname
         """
-        return self._values.get('alias_name')
+        return self._values.get("alias_name")
 
     @builtins.property
     def target_key_id(self) -> str:
@@ -256,7 +328,7 @@ class CfnAliasProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-targetkeyid
         """
-        return self._values.get('target_key_id')
+        return self._values.get("target_key_id")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -265,11 +337,17 @@ class CfnAliasProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnAliasProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnAliasProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnKey(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_kms.CfnKey"):
+class CfnKey(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_kms.CfnKey",
+):
     """A CloudFormation ``AWS::KMS::Key``.
 
     see
@@ -277,7 +355,22 @@ class CfnKey(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
     cloudformationResource:
     :cloudformationResource:: AWS::KMS::Key
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, key_policy: typing.Any, description: typing.Optional[str]=None, enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, enable_key_rotation: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, key_usage: typing.Optional[str]=None, pending_window_in_days: typing.Optional[jsii.Number]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        key_policy: typing.Any,
+        description: typing.Optional[str] = None,
+        enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        enable_key_rotation: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        key_usage: typing.Optional[str] = None,
+        pending_window_in_days: typing.Optional[jsii.Number] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Create a new ``AWS::KMS::Key``.
 
         :param scope: - scope in which this resource is defined.
@@ -290,13 +383,28 @@ class CfnKey(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
         :param pending_window_in_days: ``AWS::KMS::Key.PendingWindowInDays``.
         :param tags: ``AWS::KMS::Key.Tags``.
         """
-        props = CfnKeyProps(key_policy=key_policy, description=description, enabled=enabled, enable_key_rotation=enable_key_rotation, key_usage=key_usage, pending_window_in_days=pending_window_in_days, tags=tags)
+        props = CfnKeyProps(
+            key_policy=key_policy,
+            description=description,
+            enabled=enabled,
+            enable_key_rotation=enable_key_rotation,
+            key_usage=key_usage,
+            pending_window_in_days=pending_window_in_days,
+            tags=tags,
+        )
 
         jsii.create(CfnKey, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnKey":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnKey":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -311,7 +419,9 @@ class CfnKey(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -325,7 +435,9 @@ class CfnKey(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -400,12 +512,16 @@ class CfnKey(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
         return jsii.get(self, "enabled")
 
     @enabled.setter
-    def enabled(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def enabled(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "enabled", value)
 
     @builtins.property
     @jsii.member(jsii_name="enableKeyRotation")
-    def enable_key_rotation(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def enable_key_rotation(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::KMS::Key.EnableKeyRotation``.
 
         see
@@ -414,7 +530,9 @@ class CfnKey(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
         return jsii.get(self, "enableKeyRotation")
 
     @enable_key_rotation.setter
-    def enable_key_rotation(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def enable_key_rotation(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "enableKeyRotation", value)
 
     @builtins.property
@@ -446,9 +564,33 @@ class CfnKey(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-
         jsii.set(self, "pendingWindowInDays", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kms.CfnKeyProps", jsii_struct_bases=[], name_mapping={'key_policy': 'keyPolicy', 'description': 'description', 'enabled': 'enabled', 'enable_key_rotation': 'enableKeyRotation', 'key_usage': 'keyUsage', 'pending_window_in_days': 'pendingWindowInDays', 'tags': 'tags'})
-class CfnKeyProps():
-    def __init__(self, *, key_policy: typing.Any, description: typing.Optional[str]=None, enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, enable_key_rotation: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, key_usage: typing.Optional[str]=None, pending_window_in_days: typing.Optional[jsii.Number]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kms.CfnKeyProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "key_policy": "keyPolicy",
+        "description": "description",
+        "enabled": "enabled",
+        "enable_key_rotation": "enableKeyRotation",
+        "key_usage": "keyUsage",
+        "pending_window_in_days": "pendingWindowInDays",
+        "tags": "tags",
+    },
+)
+class CfnKeyProps:
+    def __init__(
+        self,
+        *,
+        key_policy: typing.Any,
+        description: typing.Optional[str] = None,
+        enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        enable_key_rotation: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        key_usage: typing.Optional[str] = None,
+        pending_window_in_days: typing.Optional[jsii.Number] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::KMS::Key``.
 
         :param key_policy: ``AWS::KMS::Key.KeyPolicy``.
@@ -463,14 +605,20 @@ class CfnKeyProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html
         """
         self._values = {
-            'key_policy': key_policy,
+            "key_policy": key_policy,
         }
-        if description is not None: self._values["description"] = description
-        if enabled is not None: self._values["enabled"] = enabled
-        if enable_key_rotation is not None: self._values["enable_key_rotation"] = enable_key_rotation
-        if key_usage is not None: self._values["key_usage"] = key_usage
-        if pending_window_in_days is not None: self._values["pending_window_in_days"] = pending_window_in_days
-        if tags is not None: self._values["tags"] = tags
+        if description is not None:
+            self._values["description"] = description
+        if enabled is not None:
+            self._values["enabled"] = enabled
+        if enable_key_rotation is not None:
+            self._values["enable_key_rotation"] = enable_key_rotation
+        if key_usage is not None:
+            self._values["key_usage"] = key_usage
+        if pending_window_in_days is not None:
+            self._values["pending_window_in_days"] = pending_window_in_days
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def key_policy(self) -> typing.Any:
@@ -479,7 +627,7 @@ class CfnKeyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keypolicy
         """
-        return self._values.get('key_policy')
+        return self._values.get("key_policy")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -488,7 +636,7 @@ class CfnKeyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def enabled(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
@@ -497,16 +645,18 @@ class CfnKeyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enabled
         """
-        return self._values.get('enabled')
+        return self._values.get("enabled")
 
     @builtins.property
-    def enable_key_rotation(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def enable_key_rotation(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::KMS::Key.EnableKeyRotation``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enablekeyrotation
         """
-        return self._values.get('enable_key_rotation')
+        return self._values.get("enable_key_rotation")
 
     @builtins.property
     def key_usage(self) -> typing.Optional[str]:
@@ -515,7 +665,7 @@ class CfnKeyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keyusage
         """
-        return self._values.get('key_usage')
+        return self._values.get("key_usage")
 
     @builtins.property
     def pending_window_in_days(self) -> typing.Optional[jsii.Number]:
@@ -524,7 +674,7 @@ class CfnKeyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-pendingwindowindays
         """
-        return self._values.get('pending_window_in_days')
+        return self._values.get("pending_window_in_days")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -533,7 +683,7 @@ class CfnKeyProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -542,7 +692,9 @@ class CfnKeyProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnKeyProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnKeyProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.interface(jsii_type="monocdk-experiment.aws_kms.IKey")
@@ -552,6 +704,7 @@ class IKey(_IResource_72f7ee7e, jsii.compat.Protocol):
     stability
     :stability: experimental
     """
+
     @builtins.staticmethod
     def __jsii_proxy_class__():
         return _IKeyProxy
@@ -592,7 +745,11 @@ class IKey(_IResource_72f7ee7e, jsii.compat.Protocol):
         ...
 
     @jsii.member(jsii_name="addToResourcePolicy")
-    def add_to_resource_policy(self, statement: _PolicyStatement_f75dc775, allow_no_op: typing.Optional[bool]=None) -> _AddToResourcePolicyResult_d2a345d1:
+    def add_to_resource_policy(
+        self,
+        statement: _PolicyStatement_f75dc775,
+        allow_no_op: typing.Optional[bool] = None,
+    ) -> _AddToResourcePolicyResult_d2a345d1:
         """Adds a statement to the KMS key resource policy.
 
         :param statement: The policy statement to add.
@@ -655,7 +812,9 @@ class _IKeyProxy(jsii.proxy_for(_IResource_72f7ee7e)):
     stability
     :stability: experimental
     """
+
     __jsii_type__ = "monocdk-experiment.aws_kms.IKey"
+
     @builtins.property
     @jsii.member(jsii_name="keyArn")
     def key_arn(self) -> str:
@@ -692,7 +851,11 @@ class _IKeyProxy(jsii.proxy_for(_IResource_72f7ee7e)):
         return jsii.invoke(self, "addAlias", [alias])
 
     @jsii.member(jsii_name="addToResourcePolicy")
-    def add_to_resource_policy(self, statement: _PolicyStatement_f75dc775, allow_no_op: typing.Optional[bool]=None) -> _AddToResourcePolicyResult_d2a345d1:
+    def add_to_resource_policy(
+        self,
+        statement: _PolicyStatement_f75dc775,
+        allow_no_op: typing.Optional[bool] = None,
+    ) -> _AddToResourcePolicyResult_d2a345d1:
         """Adds a statement to the KMS key resource policy.
 
         :param statement: The policy statement to add.
@@ -750,7 +913,11 @@ class _IKeyProxy(jsii.proxy_for(_IResource_72f7ee7e)):
 
 
 @jsii.implements(IKey)
-class Key(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_kms.Key"):
+class Key(
+    _Resource_884d0774,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_kms.Key",
+):
     """Defines a KMS key.
 
     stability
@@ -758,7 +925,20 @@ class Key(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experi
     resource:
     :resource:: AWS::KMS::Key
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, alias: typing.Optional[str]=None, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[_PolicyDocument_1d1bca11]=None, removal_policy: typing.Optional[_RemovalPolicy_5986e9f3]=None, trust_account_identities: typing.Optional[bool]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        alias: typing.Optional[str] = None,
+        description: typing.Optional[str] = None,
+        enabled: typing.Optional[bool] = None,
+        enable_key_rotation: typing.Optional[bool] = None,
+        policy: typing.Optional[_PolicyDocument_1d1bca11] = None,
+        removal_policy: typing.Optional[_RemovalPolicy_5986e9f3] = None,
+        trust_account_identities: typing.Optional[bool] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -773,7 +953,15 @@ class Key(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experi
         stability
         :stability: experimental
         """
-        props = KeyProps(alias=alias, description=description, enabled=enabled, enable_key_rotation=enable_key_rotation, policy=policy, removal_policy=removal_policy, trust_account_identities=trust_account_identities)
+        props = KeyProps(
+            alias=alias,
+            description=description,
+            enabled=enabled,
+            enable_key_rotation=enable_key_rotation,
+            policy=policy,
+            removal_policy=removal_policy,
+            trust_account_identities=trust_account_identities,
+        )
 
         jsii.create(Key, self, [scope, id, props])
 
@@ -803,7 +991,11 @@ class Key(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experi
         return jsii.invoke(self, "addAlias", [alias_name])
 
     @jsii.member(jsii_name="addToResourcePolicy")
-    def add_to_resource_policy(self, statement: _PolicyStatement_f75dc775, allow_no_op: typing.Optional[bool]=None) -> _AddToResourcePolicyResult_d2a345d1:
+    def add_to_resource_policy(
+        self,
+        statement: _PolicyStatement_f75dc775,
+        allow_no_op: typing.Optional[bool] = None,
+    ) -> _AddToResourcePolicyResult_d2a345d1:
         """Adds a statement to the KMS key resource policy.
 
         :param statement: The policy statement to add.
@@ -910,9 +1102,31 @@ class Key(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experi
         return jsii.get(self, "policy")
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_kms.KeyProps", jsii_struct_bases=[], name_mapping={'alias': 'alias', 'description': 'description', 'enabled': 'enabled', 'enable_key_rotation': 'enableKeyRotation', 'policy': 'policy', 'removal_policy': 'removalPolicy', 'trust_account_identities': 'trustAccountIdentities'})
-class KeyProps():
-    def __init__(self, *, alias: typing.Optional[str]=None, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[_PolicyDocument_1d1bca11]=None, removal_policy: typing.Optional[_RemovalPolicy_5986e9f3]=None, trust_account_identities: typing.Optional[bool]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_kms.KeyProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "alias": "alias",
+        "description": "description",
+        "enabled": "enabled",
+        "enable_key_rotation": "enableKeyRotation",
+        "policy": "policy",
+        "removal_policy": "removalPolicy",
+        "trust_account_identities": "trustAccountIdentities",
+    },
+)
+class KeyProps:
+    def __init__(
+        self,
+        *,
+        alias: typing.Optional[str] = None,
+        description: typing.Optional[str] = None,
+        enabled: typing.Optional[bool] = None,
+        enable_key_rotation: typing.Optional[bool] = None,
+        policy: typing.Optional[_PolicyDocument_1d1bca11] = None,
+        removal_policy: typing.Optional[_RemovalPolicy_5986e9f3] = None,
+        trust_account_identities: typing.Optional[bool] = None,
+    ) -> None:
         """Construction properties for a KMS Key object.
 
         :param alias: Initial alias to add to the key. More aliases can be added later by calling ``addAlias``. Default: - No alias is added for the key.
@@ -926,15 +1140,21 @@ class KeyProps():
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if alias is not None: self._values["alias"] = alias
-        if description is not None: self._values["description"] = description
-        if enabled is not None: self._values["enabled"] = enabled
-        if enable_key_rotation is not None: self._values["enable_key_rotation"] = enable_key_rotation
-        if policy is not None: self._values["policy"] = policy
-        if removal_policy is not None: self._values["removal_policy"] = removal_policy
-        if trust_account_identities is not None: self._values["trust_account_identities"] = trust_account_identities
+        self._values = {}
+        if alias is not None:
+            self._values["alias"] = alias
+        if description is not None:
+            self._values["description"] = description
+        if enabled is not None:
+            self._values["enabled"] = enabled
+        if enable_key_rotation is not None:
+            self._values["enable_key_rotation"] = enable_key_rotation
+        if policy is not None:
+            self._values["policy"] = policy
+        if removal_policy is not None:
+            self._values["removal_policy"] = removal_policy
+        if trust_account_identities is not None:
+            self._values["trust_account_identities"] = trust_account_identities
 
     @builtins.property
     def alias(self) -> typing.Optional[str]:
@@ -948,7 +1168,7 @@ class KeyProps():
         stability
         :stability: experimental
         """
-        return self._values.get('alias')
+        return self._values.get("alias")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -963,7 +1183,7 @@ class KeyProps():
         stability
         :stability: experimental
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
     def enabled(self) -> typing.Optional[bool]:
@@ -975,7 +1195,7 @@ class KeyProps():
         stability
         :stability: experimental
         """
-        return self._values.get('enabled')
+        return self._values.get("enabled")
 
     @builtins.property
     def enable_key_rotation(self) -> typing.Optional[bool]:
@@ -987,7 +1207,7 @@ class KeyProps():
         stability
         :stability: experimental
         """
-        return self._values.get('enable_key_rotation')
+        return self._values.get("enable_key_rotation")
 
     @builtins.property
     def policy(self) -> typing.Optional[_PolicyDocument_1d1bca11]:
@@ -1002,7 +1222,7 @@ class KeyProps():
         stability
         :stability: experimental
         """
-        return self._values.get('policy')
+        return self._values.get("policy")
 
     @builtins.property
     def removal_policy(self) -> typing.Optional[_RemovalPolicy_5986e9f3]:
@@ -1017,7 +1237,7 @@ class KeyProps():
         stability
         :stability: experimental
         """
-        return self._values.get('removal_policy')
+        return self._values.get("removal_policy")
 
     @builtins.property
     def trust_account_identities(self) -> typing.Optional[bool]:
@@ -1035,7 +1255,7 @@ class KeyProps():
         stability
         :stability: experimental
         """
-        return self._values.get('trust_account_identities')
+        return self._values.get("trust_account_identities")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1044,16 +1264,27 @@ class KeyProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'KeyProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "KeyProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-class ViaServicePrincipal(_PrincipalBase_e4459eeb, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_kms.ViaServicePrincipal"):
+class ViaServicePrincipal(
+    _PrincipalBase_e4459eeb,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_kms.ViaServicePrincipal",
+):
     """A principal to allow access to a key if it's being used through another AWS service.
 
     stability
     :stability: experimental
     """
-    def __init__(self, service_name: str, base_principal: typing.Optional[_IPrincipal_97126874]=None) -> None:
+
+    def __init__(
+        self,
+        service_name: str,
+        base_principal: typing.Optional[_IPrincipal_97126874] = None,
+    ) -> None:
         """
         :param service_name: -
         :param base_principal: -
@@ -1083,6 +1314,7 @@ class IAlias(IKey, jsii.compat.Protocol):
     stability
     :stability: experimental
     """
+
     @builtins.staticmethod
     def __jsii_proxy_class__():
         return _IAliasProxy
@@ -1120,7 +1352,9 @@ class _IAliasProxy(jsii.proxy_for(IKey)):
     stability
     :stability: experimental
     """
+
     __jsii_type__ = "monocdk-experiment.aws_kms.IAlias"
+
     @builtins.property
     @jsii.member(jsii_name="aliasName")
     def alias_name(self) -> str:
@@ -1147,7 +1381,11 @@ class _IAliasProxy(jsii.proxy_for(IKey)):
 
 
 @jsii.implements(IAlias)
-class Alias(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_kms.Alias"):
+class Alias(
+    _Resource_884d0774,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_kms.Alias",
+):
     """Defines a display name for a customer master key (CMK) in AWS Key Management Service (AWS KMS).
 
     Using an alias to refer to a key can help you simplify key
@@ -1162,7 +1400,16 @@ class Alias(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
     resource:
     :resource:: AWS::KMS::Alias
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, alias_name: str, target_key: "IKey", removal_policy: typing.Optional[_RemovalPolicy_5986e9f3]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        alias_name: str,
+        target_key: "IKey",
+        removal_policy: typing.Optional[_RemovalPolicy_5986e9f3] = None,
+    ) -> None:
         """
         :param scope: -
         :param id: -
@@ -1173,13 +1420,22 @@ class Alias(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
         stability
         :stability: experimental
         """
-        props = AliasProps(alias_name=alias_name, target_key=target_key, removal_policy=removal_policy)
+        props = AliasProps(
+            alias_name=alias_name, target_key=target_key, removal_policy=removal_policy
+        )
 
         jsii.create(Alias, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromAliasAttributes")
     @builtins.classmethod
-    def from_alias_attributes(cls, scope: _Construct_f50a3f53, id: str, *, alias_name: str, alias_target_key: "IKey") -> "IAlias":
+    def from_alias_attributes(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        alias_name: str,
+        alias_target_key: "IKey",
+    ) -> "IAlias":
         """Import an existing KMS Alias defined outside the CDK app.
 
         :param scope: The parent creating construct (usually ``this``).
@@ -1190,13 +1446,17 @@ class Alias(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
         stability
         :stability: experimental
         """
-        attrs = AliasAttributes(alias_name=alias_name, alias_target_key=alias_target_key)
+        attrs = AliasAttributes(
+            alias_name=alias_name, alias_target_key=alias_target_key
+        )
 
         return jsii.sinvoke(cls, "fromAliasAttributes", [scope, id, attrs])
 
     @jsii.member(jsii_name="fromAliasName")
     @builtins.classmethod
-    def from_alias_name(cls, scope: _Construct_f50a3f53, id: str, alias_name: str) -> "IAlias":
+    def from_alias_name(
+        cls, scope: _Construct_f50a3f53, id: str, alias_name: str
+    ) -> "IAlias":
         """Import an existing KMS Alias defined outside the CDK app, by the alias name.
 
         This method should be used
@@ -1224,7 +1484,11 @@ class Alias(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
         return jsii.invoke(self, "addAlias", [alias])
 
     @jsii.member(jsii_name="addToResourcePolicy")
-    def add_to_resource_policy(self, statement: _PolicyStatement_f75dc775, allow_no_op: typing.Optional[bool]=None) -> _AddToResourcePolicyResult_d2a345d1:
+    def add_to_resource_policy(
+        self,
+        statement: _PolicyStatement_f75dc775,
+        allow_no_op: typing.Optional[bool] = None,
+    ) -> _AddToResourcePolicyResult_d2a345d1:
         """Adds a statement to the KMS key resource policy.
 
         :param statement: -
