@@ -10,11 +10,25 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, CfnTag as _CfnTag_b4661f1a)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_mediastore.CfnContainer"):
+class CfnContainer(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_mediastore.CfnContainer",
+):
     """A CloudFormation ``AWS::MediaStore::Container``.
 
     see
@@ -22,7 +36,29 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
     cloudformationResource:
     :cloudformationResource:: AWS::MediaStore::Container
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, container_name: str, access_logging_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]]=None, lifecycle_policy: typing.Optional[str]=None, metric_policy: typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]]=None, policy: typing.Optional[str]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        container_name: str,
+        access_logging_enabled: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        cors_policy: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]],
+            ]
+        ] = None,
+        lifecycle_policy: typing.Optional[str] = None,
+        metric_policy: typing.Optional[
+            typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]
+        ] = None,
+        policy: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Create a new ``AWS::MediaStore::Container``.
 
         :param scope: - scope in which this resource is defined.
@@ -35,13 +71,28 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         :param policy: ``AWS::MediaStore::Container.Policy``.
         :param tags: ``AWS::MediaStore::Container.Tags``.
         """
-        props = CfnContainerProps(container_name=container_name, access_logging_enabled=access_logging_enabled, cors_policy=cors_policy, lifecycle_policy=lifecycle_policy, metric_policy=metric_policy, policy=policy, tags=tags)
+        props = CfnContainerProps(
+            container_name=container_name,
+            access_logging_enabled=access_logging_enabled,
+            cors_policy=cors_policy,
+            lifecycle_policy=lifecycle_policy,
+            metric_policy=metric_policy,
+            policy=policy,
+            tags=tags,
+        )
 
         jsii.create(CfnContainer, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnContainer":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnContainer":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -56,7 +107,9 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -70,7 +123,9 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -122,7 +177,9 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
 
     @builtins.property
     @jsii.member(jsii_name="accessLoggingEnabled")
-    def access_logging_enabled(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def access_logging_enabled(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.AccessLoggingEnabled``.
 
         see
@@ -131,12 +188,21 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.get(self, "accessLoggingEnabled")
 
     @access_logging_enabled.setter
-    def access_logging_enabled(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def access_logging_enabled(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "accessLoggingEnabled", value)
 
     @builtins.property
     @jsii.member(jsii_name="corsPolicy")
-    def cors_policy(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]]:
+    def cors_policy(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]],
+        ]
+    ]:
         """``AWS::MediaStore::Container.CorsPolicy``.
 
         see
@@ -145,7 +211,15 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.get(self, "corsPolicy")
 
     @cors_policy.setter
-    def cors_policy(self, value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]]) -> None:
+    def cors_policy(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "corsPolicy", value)
 
     @builtins.property
@@ -164,7 +238,9 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
 
     @builtins.property
     @jsii.member(jsii_name="metricPolicy")
-    def metric_policy(self) -> typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]]:
+    def metric_policy(
+        self,
+    ) -> typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.MetricPolicy``.
 
         see
@@ -173,7 +249,12 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.get(self, "metricPolicy")
 
     @metric_policy.setter
-    def metric_policy(self, value: typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]]) -> None:
+    def metric_policy(
+        self,
+        value: typing.Optional[
+            typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
         jsii.set(self, "metricPolicy", value)
 
     @builtins.property
@@ -190,9 +271,27 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
     def policy(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "policy", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_mediastore.CfnContainer.CorsRuleProperty", jsii_struct_bases=[], name_mapping={'allowed_headers': 'allowedHeaders', 'allowed_methods': 'allowedMethods', 'allowed_origins': 'allowedOrigins', 'expose_headers': 'exposeHeaders', 'max_age_seconds': 'maxAgeSeconds'})
-    class CorsRuleProperty():
-        def __init__(self, *, allowed_headers: typing.Optional[typing.List[str]]=None, allowed_methods: typing.Optional[typing.List[str]]=None, allowed_origins: typing.Optional[typing.List[str]]=None, expose_headers: typing.Optional[typing.List[str]]=None, max_age_seconds: typing.Optional[jsii.Number]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_mediastore.CfnContainer.CorsRuleProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "allowed_headers": "allowedHeaders",
+            "allowed_methods": "allowedMethods",
+            "allowed_origins": "allowedOrigins",
+            "expose_headers": "exposeHeaders",
+            "max_age_seconds": "maxAgeSeconds",
+        },
+    )
+    class CorsRuleProperty:
+        def __init__(
+            self,
+            *,
+            allowed_headers: typing.Optional[typing.List[str]] = None,
+            allowed_methods: typing.Optional[typing.List[str]] = None,
+            allowed_origins: typing.Optional[typing.List[str]] = None,
+            expose_headers: typing.Optional[typing.List[str]] = None,
+            max_age_seconds: typing.Optional[jsii.Number] = None,
+        ) -> None:
             """
             :param allowed_headers: ``CfnContainer.CorsRuleProperty.AllowedHeaders``.
             :param allowed_methods: ``CfnContainer.CorsRuleProperty.AllowedMethods``.
@@ -203,13 +302,17 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html
             """
-            self._values = {
-            }
-            if allowed_headers is not None: self._values["allowed_headers"] = allowed_headers
-            if allowed_methods is not None: self._values["allowed_methods"] = allowed_methods
-            if allowed_origins is not None: self._values["allowed_origins"] = allowed_origins
-            if expose_headers is not None: self._values["expose_headers"] = expose_headers
-            if max_age_seconds is not None: self._values["max_age_seconds"] = max_age_seconds
+            self._values = {}
+            if allowed_headers is not None:
+                self._values["allowed_headers"] = allowed_headers
+            if allowed_methods is not None:
+                self._values["allowed_methods"] = allowed_methods
+            if allowed_origins is not None:
+                self._values["allowed_origins"] = allowed_origins
+            if expose_headers is not None:
+                self._values["expose_headers"] = expose_headers
+            if max_age_seconds is not None:
+                self._values["max_age_seconds"] = max_age_seconds
 
         @builtins.property
         def allowed_headers(self) -> typing.Optional[typing.List[str]]:
@@ -218,7 +321,7 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedheaders
             """
-            return self._values.get('allowed_headers')
+            return self._values.get("allowed_headers")
 
         @builtins.property
         def allowed_methods(self) -> typing.Optional[typing.List[str]]:
@@ -227,7 +330,7 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedmethods
             """
-            return self._values.get('allowed_methods')
+            return self._values.get("allowed_methods")
 
         @builtins.property
         def allowed_origins(self) -> typing.Optional[typing.List[str]]:
@@ -236,7 +339,7 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-allowedorigins
             """
-            return self._values.get('allowed_origins')
+            return self._values.get("allowed_origins")
 
         @builtins.property
         def expose_headers(self) -> typing.Optional[typing.List[str]]:
@@ -245,7 +348,7 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-exposeheaders
             """
-            return self._values.get('expose_headers')
+            return self._values.get("expose_headers")
 
         @builtins.property
         def max_age_seconds(self) -> typing.Optional[jsii.Number]:
@@ -254,7 +357,7 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-corsrule.html#cfn-mediastore-container-corsrule-maxageseconds
             """
-            return self._values.get('max_age_seconds')
+            return self._values.get("max_age_seconds")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -263,12 +366,35 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'CorsRuleProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "CorsRuleProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_mediastore.CfnContainer.MetricPolicyProperty", jsii_struct_bases=[], name_mapping={'container_level_metrics': 'containerLevelMetrics', 'metric_policy_rules': 'metricPolicyRules'})
-    class MetricPolicyProperty():
-        def __init__(self, *, container_level_metrics: str, metric_policy_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.MetricPolicyRuleProperty", _IResolvable_9ceae33e]]]]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_mediastore.CfnContainer.MetricPolicyProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "container_level_metrics": "containerLevelMetrics",
+            "metric_policy_rules": "metricPolicyRules",
+        },
+    )
+    class MetricPolicyProperty:
+        def __init__(
+            self,
+            *,
+            container_level_metrics: str,
+            metric_policy_rules: typing.Optional[
+                typing.Union[
+                    _IResolvable_9ceae33e,
+                    typing.List[
+                        typing.Union[
+                            "CfnContainer.MetricPolicyRuleProperty",
+                            _IResolvable_9ceae33e,
+                        ]
+                    ],
+                ]
+            ] = None,
+        ) -> None:
             """
             :param container_level_metrics: ``CfnContainer.MetricPolicyProperty.ContainerLevelMetrics``.
             :param metric_policy_rules: ``CfnContainer.MetricPolicyProperty.MetricPolicyRules``.
@@ -277,9 +403,10 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html
             """
             self._values = {
-                'container_level_metrics': container_level_metrics,
+                "container_level_metrics": container_level_metrics,
             }
-            if metric_policy_rules is not None: self._values["metric_policy_rules"] = metric_policy_rules
+            if metric_policy_rules is not None:
+                self._values["metric_policy_rules"] = metric_policy_rules
 
         @builtins.property
         def container_level_metrics(self) -> str:
@@ -288,16 +415,27 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html#cfn-mediastore-container-metricpolicy-containerlevelmetrics
             """
-            return self._values.get('container_level_metrics')
+            return self._values.get("container_level_metrics")
 
         @builtins.property
-        def metric_policy_rules(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.MetricPolicyRuleProperty", _IResolvable_9ceae33e]]]]:
+        def metric_policy_rules(
+            self,
+        ) -> typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "CfnContainer.MetricPolicyRuleProperty", _IResolvable_9ceae33e
+                    ]
+                ],
+            ]
+        ]:
             """``CfnContainer.MetricPolicyProperty.MetricPolicyRules``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicy.html#cfn-mediastore-container-metricpolicy-metricpolicyrules
             """
-            return self._values.get('metric_policy_rules')
+            return self._values.get("metric_policy_rules")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -306,11 +444,19 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'MetricPolicyProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "MetricPolicyProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
-
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_mediastore.CfnContainer.MetricPolicyRuleProperty", jsii_struct_bases=[], name_mapping={'object_group': 'objectGroup', 'object_group_name': 'objectGroupName'})
-    class MetricPolicyRuleProperty():
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_mediastore.CfnContainer.MetricPolicyRuleProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "object_group": "objectGroup",
+            "object_group_name": "objectGroupName",
+        },
+    )
+    class MetricPolicyRuleProperty:
         def __init__(self, *, object_group: str, object_group_name: str) -> None:
             """
             :param object_group: ``CfnContainer.MetricPolicyRuleProperty.ObjectGroup``.
@@ -320,8 +466,8 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html
             """
             self._values = {
-                'object_group': object_group,
-                'object_group_name': object_group_name,
+                "object_group": object_group,
+                "object_group_name": object_group_name,
             }
 
         @builtins.property
@@ -331,7 +477,7 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html#cfn-mediastore-container-metricpolicyrule-objectgroup
             """
-            return self._values.get('object_group')
+            return self._values.get("object_group")
 
         @builtins.property
         def object_group_name(self) -> str:
@@ -340,7 +486,7 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediastore-container-metricpolicyrule.html#cfn-mediastore-container-metricpolicyrule-objectgroupname
             """
-            return self._values.get('object_group_name')
+            return self._values.get("object_group_name")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -349,13 +495,47 @@ class CfnContainer(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'MetricPolicyRuleProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "MetricPolicyRuleProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_mediastore.CfnContainerProps", jsii_struct_bases=[], name_mapping={'container_name': 'containerName', 'access_logging_enabled': 'accessLoggingEnabled', 'cors_policy': 'corsPolicy', 'lifecycle_policy': 'lifecyclePolicy', 'metric_policy': 'metricPolicy', 'policy': 'policy', 'tags': 'tags'})
-class CfnContainerProps():
-    def __init__(self, *, container_name: str, access_logging_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]]=None, lifecycle_policy: typing.Optional[str]=None, metric_policy: typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]]=None, policy: typing.Optional[str]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_mediastore.CfnContainerProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "container_name": "containerName",
+        "access_logging_enabled": "accessLoggingEnabled",
+        "cors_policy": "corsPolicy",
+        "lifecycle_policy": "lifecyclePolicy",
+        "metric_policy": "metricPolicy",
+        "policy": "policy",
+        "tags": "tags",
+    },
+)
+class CfnContainerProps:
+    def __init__(
+        self,
+        *,
+        container_name: str,
+        access_logging_enabled: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        cors_policy: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]
+                ],
+            ]
+        ] = None,
+        lifecycle_policy: typing.Optional[str] = None,
+        metric_policy: typing.Optional[
+            typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]
+        ] = None,
+        policy: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::MediaStore::Container``.
 
         :param container_name: ``AWS::MediaStore::Container.ContainerName``.
@@ -370,14 +550,20 @@ class CfnContainerProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html
         """
         self._values = {
-            'container_name': container_name,
+            "container_name": container_name,
         }
-        if access_logging_enabled is not None: self._values["access_logging_enabled"] = access_logging_enabled
-        if cors_policy is not None: self._values["cors_policy"] = cors_policy
-        if lifecycle_policy is not None: self._values["lifecycle_policy"] = lifecycle_policy
-        if metric_policy is not None: self._values["metric_policy"] = metric_policy
-        if policy is not None: self._values["policy"] = policy
-        if tags is not None: self._values["tags"] = tags
+        if access_logging_enabled is not None:
+            self._values["access_logging_enabled"] = access_logging_enabled
+        if cors_policy is not None:
+            self._values["cors_policy"] = cors_policy
+        if lifecycle_policy is not None:
+            self._values["lifecycle_policy"] = lifecycle_policy
+        if metric_policy is not None:
+            self._values["metric_policy"] = metric_policy
+        if policy is not None:
+            self._values["policy"] = policy
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def container_name(self) -> str:
@@ -386,25 +572,36 @@ class CfnContainerProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-containername
         """
-        return self._values.get('container_name')
+        return self._values.get("container_name")
 
     @builtins.property
-    def access_logging_enabled(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def access_logging_enabled(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.AccessLoggingEnabled``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-accessloggingenabled
         """
-        return self._values.get('access_logging_enabled')
+        return self._values.get("access_logging_enabled")
 
     @builtins.property
-    def cors_policy(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]]:
+    def cors_policy(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]
+            ],
+        ]
+    ]:
         """``AWS::MediaStore::Container.CorsPolicy``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-corspolicy
         """
-        return self._values.get('cors_policy')
+        return self._values.get("cors_policy")
 
     @builtins.property
     def lifecycle_policy(self) -> typing.Optional[str]:
@@ -413,16 +610,20 @@ class CfnContainerProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-lifecyclepolicy
         """
-        return self._values.get('lifecycle_policy')
+        return self._values.get("lifecycle_policy")
 
     @builtins.property
-    def metric_policy(self) -> typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]]:
+    def metric_policy(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::MediaStore::Container.MetricPolicy``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-metricpolicy
         """
-        return self._values.get('metric_policy')
+        return self._values.get("metric_policy")
 
     @builtins.property
     def policy(self) -> typing.Optional[str]:
@@ -431,7 +632,7 @@ class CfnContainerProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-policy
         """
-        return self._values.get('policy')
+        return self._values.get("policy")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -440,7 +641,7 @@ class CfnContainerProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediastore-container.html#cfn-mediastore-container-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -449,7 +650,9 @@ class CfnContainerProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnContainerProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnContainerProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
