@@ -10,11 +10,25 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, CfnTag as _CfnTag_b4661f1a)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverEndpoint"):
+class CfnResolverEndpoint(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverEndpoint",
+):
     """A CloudFormation ``AWS::Route53Resolver::ResolverEndpoint``.
 
     see
@@ -22,7 +36,23 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
     cloudformationResource:
     :cloudformationResource:: AWS::Route53Resolver::ResolverEndpoint
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, direction: str, ip_addresses: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["IpAddressRequestProperty", _IResolvable_9ceae33e]]], security_group_ids: typing.List[str], name: typing.Optional[str]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        direction: str,
+        ip_addresses: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union["IpAddressRequestProperty", _IResolvable_9ceae33e]
+            ],
+        ],
+        security_group_ids: typing.List[str],
+        name: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Create a new ``AWS::Route53Resolver::ResolverEndpoint``.
 
         :param scope: - scope in which this resource is defined.
@@ -33,13 +63,26 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         :param name: ``AWS::Route53Resolver::ResolverEndpoint.Name``.
         :param tags: ``AWS::Route53Resolver::ResolverEndpoint.Tags``.
         """
-        props = CfnResolverEndpointProps(direction=direction, ip_addresses=ip_addresses, security_group_ids=security_group_ids, name=name, tags=tags)
+        props = CfnResolverEndpointProps(
+            direction=direction,
+            ip_addresses=ip_addresses,
+            security_group_ids=security_group_ids,
+            name=name,
+            tags=tags,
+        )
 
         jsii.create(CfnResolverEndpoint, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnResolverEndpoint":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnResolverEndpoint":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -54,7 +97,9 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -68,7 +113,9 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -165,7 +212,12 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
 
     @builtins.property
     @jsii.member(jsii_name="ipAddresses")
-    def ip_addresses(self) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["IpAddressRequestProperty", _IResolvable_9ceae33e]]]:
+    def ip_addresses(
+        self,
+    ) -> typing.Union[
+        _IResolvable_9ceae33e,
+        typing.List[typing.Union["IpAddressRequestProperty", _IResolvable_9ceae33e]],
+    ]:
         """``AWS::Route53Resolver::ResolverEndpoint.IpAddresses``.
 
         see
@@ -174,7 +226,15 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
         return jsii.get(self, "ipAddresses")
 
     @ip_addresses.setter
-    def ip_addresses(self, value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["IpAddressRequestProperty", _IResolvable_9ceae33e]]]) -> None:
+    def ip_addresses(
+        self,
+        value: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union["IpAddressRequestProperty", _IResolvable_9ceae33e]
+            ],
+        ],
+    ) -> None:
         jsii.set(self, "ipAddresses", value)
 
     @builtins.property
@@ -205,9 +265,13 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
     def name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "name", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverEndpoint.IpAddressRequestProperty", jsii_struct_bases=[], name_mapping={'subnet_id': 'subnetId', 'ip': 'ip'})
-    class IpAddressRequestProperty():
-        def __init__(self, *, subnet_id: str, ip: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverEndpoint.IpAddressRequestProperty",
+        jsii_struct_bases=[],
+        name_mapping={"subnet_id": "subnetId", "ip": "ip"},
+    )
+    class IpAddressRequestProperty:
+        def __init__(self, *, subnet_id: str, ip: typing.Optional[str] = None) -> None:
             """
             :param subnet_id: ``CfnResolverEndpoint.IpAddressRequestProperty.SubnetId``.
             :param ip: ``CfnResolverEndpoint.IpAddressRequestProperty.Ip``.
@@ -216,9 +280,10 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-resolverendpoint-ipaddressrequest.html
             """
             self._values = {
-                'subnet_id': subnet_id,
+                "subnet_id": subnet_id,
             }
-            if ip is not None: self._values["ip"] = ip
+            if ip is not None:
+                self._values["ip"] = ip
 
         @builtins.property
         def subnet_id(self) -> str:
@@ -227,7 +292,7 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-resolverendpoint-ipaddressrequest.html#cfn-route53resolver-resolverendpoint-ipaddressrequest-subnetid
             """
-            return self._values.get('subnet_id')
+            return self._values.get("subnet_id")
 
         @builtins.property
         def ip(self) -> typing.Optional[str]:
@@ -236,7 +301,7 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-resolverendpoint-ipaddressrequest.html#cfn-route53resolver-resolverendpoint-ipaddressrequest-ip
             """
-            return self._values.get('ip')
+            return self._values.get("ip")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -245,13 +310,40 @@ class CfnResolverEndpoint(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_t
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'IpAddressRequestProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "IpAddressRequestProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverEndpointProps", jsii_struct_bases=[], name_mapping={'direction': 'direction', 'ip_addresses': 'ipAddresses', 'security_group_ids': 'securityGroupIds', 'name': 'name', 'tags': 'tags'})
-class CfnResolverEndpointProps():
-    def __init__(self, *, direction: str, ip_addresses: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnResolverEndpoint.IpAddressRequestProperty", _IResolvable_9ceae33e]]], security_group_ids: typing.List[str], name: typing.Optional[str]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverEndpointProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "direction": "direction",
+        "ip_addresses": "ipAddresses",
+        "security_group_ids": "securityGroupIds",
+        "name": "name",
+        "tags": "tags",
+    },
+)
+class CfnResolverEndpointProps:
+    def __init__(
+        self,
+        *,
+        direction: str,
+        ip_addresses: typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union[
+                    "CfnResolverEndpoint.IpAddressRequestProperty",
+                    _IResolvable_9ceae33e,
+                ]
+            ],
+        ],
+        security_group_ids: typing.List[str],
+        name: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Route53Resolver::ResolverEndpoint``.
 
         :param direction: ``AWS::Route53Resolver::ResolverEndpoint.Direction``.
@@ -264,12 +356,14 @@ class CfnResolverEndpointProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverendpoint.html
         """
         self._values = {
-            'direction': direction,
-            'ip_addresses': ip_addresses,
-            'security_group_ids': security_group_ids,
+            "direction": direction,
+            "ip_addresses": ip_addresses,
+            "security_group_ids": security_group_ids,
         }
-        if name is not None: self._values["name"] = name
-        if tags is not None: self._values["tags"] = tags
+        if name is not None:
+            self._values["name"] = name
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def direction(self) -> str:
@@ -278,16 +372,25 @@ class CfnResolverEndpointProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverendpoint.html#cfn-route53resolver-resolverendpoint-direction
         """
-        return self._values.get('direction')
+        return self._values.get("direction")
 
     @builtins.property
-    def ip_addresses(self) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnResolverEndpoint.IpAddressRequestProperty", _IResolvable_9ceae33e]]]:
+    def ip_addresses(
+        self,
+    ) -> typing.Union[
+        _IResolvable_9ceae33e,
+        typing.List[
+            typing.Union[
+                "CfnResolverEndpoint.IpAddressRequestProperty", _IResolvable_9ceae33e
+            ]
+        ],
+    ]:
         """``AWS::Route53Resolver::ResolverEndpoint.IpAddresses``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverendpoint.html#cfn-route53resolver-resolverendpoint-ipaddresses
         """
-        return self._values.get('ip_addresses')
+        return self._values.get("ip_addresses")
 
     @builtins.property
     def security_group_ids(self) -> typing.List[str]:
@@ -296,7 +399,7 @@ class CfnResolverEndpointProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverendpoint.html#cfn-route53resolver-resolverendpoint-securitygroupids
         """
-        return self._values.get('security_group_ids')
+        return self._values.get("security_group_ids")
 
     @builtins.property
     def name(self) -> typing.Optional[str]:
@@ -305,7 +408,7 @@ class CfnResolverEndpointProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverendpoint.html#cfn-route53resolver-resolverendpoint-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -314,7 +417,7 @@ class CfnResolverEndpointProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverendpoint.html#cfn-route53resolver-resolverendpoint-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -323,11 +426,17 @@ class CfnResolverEndpointProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnResolverEndpointProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnResolverEndpointProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRule"):
+class CfnResolverRule(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRule",
+):
     """A CloudFormation ``AWS::Route53Resolver::ResolverRule``.
 
     see
@@ -335,7 +444,26 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
     cloudformationResource:
     :cloudformationResource:: AWS::Route53Resolver::ResolverRule
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, domain_name: str, rule_type: str, name: typing.Optional[str]=None, resolver_endpoint_id: typing.Optional[str]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None, target_ips: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["TargetAddressProperty", _IResolvable_9ceae33e]]]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        domain_name: str,
+        rule_type: str,
+        name: typing.Optional[str] = None,
+        resolver_endpoint_id: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+        target_ips: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union["TargetAddressProperty", _IResolvable_9ceae33e]
+                ],
+            ]
+        ] = None,
+    ) -> None:
         """Create a new ``AWS::Route53Resolver::ResolverRule``.
 
         :param scope: - scope in which this resource is defined.
@@ -347,13 +475,27 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
         :param tags: ``AWS::Route53Resolver::ResolverRule.Tags``.
         :param target_ips: ``AWS::Route53Resolver::ResolverRule.TargetIps``.
         """
-        props = CfnResolverRuleProps(domain_name=domain_name, rule_type=rule_type, name=name, resolver_endpoint_id=resolver_endpoint_id, tags=tags, target_ips=target_ips)
+        props = CfnResolverRuleProps(
+            domain_name=domain_name,
+            rule_type=rule_type,
+            name=name,
+            resolver_endpoint_id=resolver_endpoint_id,
+            tags=tags,
+            target_ips=target_ips,
+        )
 
         jsii.create(CfnResolverRule, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnResolverRule":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnResolverRule":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -368,7 +510,9 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -382,7 +526,9 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -521,7 +667,14 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
 
     @builtins.property
     @jsii.member(jsii_name="targetIps")
-    def target_ips(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["TargetAddressProperty", _IResolvable_9ceae33e]]]]:
+    def target_ips(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["TargetAddressProperty", _IResolvable_9ceae33e]],
+        ]
+    ]:
         """``AWS::Route53Resolver::ResolverRule.TargetIps``.
 
         see
@@ -530,12 +683,26 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "targetIps")
 
     @target_ips.setter
-    def target_ips(self, value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["TargetAddressProperty", _IResolvable_9ceae33e]]]]) -> None:
+    def target_ips(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union["TargetAddressProperty", _IResolvable_9ceae33e]
+                ],
+            ]
+        ],
+    ) -> None:
         jsii.set(self, "targetIps", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRule.TargetAddressProperty", jsii_struct_bases=[], name_mapping={'ip': 'ip', 'port': 'port'})
-    class TargetAddressProperty():
-        def __init__(self, *, ip: str, port: typing.Optional[str]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRule.TargetAddressProperty",
+        jsii_struct_bases=[],
+        name_mapping={"ip": "ip", "port": "port"},
+    )
+    class TargetAddressProperty:
+        def __init__(self, *, ip: str, port: typing.Optional[str] = None) -> None:
             """
             :param ip: ``CfnResolverRule.TargetAddressProperty.Ip``.
             :param port: ``CfnResolverRule.TargetAddressProperty.Port``.
@@ -544,9 +711,10 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-resolverrule-targetaddress.html
             """
             self._values = {
-                'ip': ip,
+                "ip": ip,
             }
-            if port is not None: self._values["port"] = port
+            if port is not None:
+                self._values["port"] = port
 
         @builtins.property
         def ip(self) -> str:
@@ -555,7 +723,7 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-resolverrule-targetaddress.html#cfn-route53resolver-resolverrule-targetaddress-ip
             """
-            return self._values.get('ip')
+            return self._values.get("ip")
 
         @builtins.property
         def port(self) -> typing.Optional[str]:
@@ -564,7 +732,7 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53resolver-resolverrule-targetaddress.html#cfn-route53resolver-resolverrule-targetaddress-port
             """
-            return self._values.get('port')
+            return self._values.get("port")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -573,12 +741,17 @@ class CfnResolverRule(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type=
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'TargetAddressProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
-
+            return "TargetAddressProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnResolverRuleAssociation(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRuleAssociation"):
+class CfnResolverRuleAssociation(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRuleAssociation",
+):
     """A CloudFormation ``AWS::Route53Resolver::ResolverRuleAssociation``.
 
     see
@@ -586,7 +759,16 @@ class CfnResolverRuleAssociation(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta,
     cloudformationResource:
     :cloudformationResource:: AWS::Route53Resolver::ResolverRuleAssociation
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, resolver_rule_id: str, vpc_id: str, name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        resolver_rule_id: str,
+        vpc_id: str,
+        name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::Route53Resolver::ResolverRuleAssociation``.
 
         :param scope: - scope in which this resource is defined.
@@ -595,13 +777,22 @@ class CfnResolverRuleAssociation(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta,
         :param vpc_id: ``AWS::Route53Resolver::ResolverRuleAssociation.VPCId``.
         :param name: ``AWS::Route53Resolver::ResolverRuleAssociation.Name``.
         """
-        props = CfnResolverRuleAssociationProps(resolver_rule_id=resolver_rule_id, vpc_id=vpc_id, name=name)
+        props = CfnResolverRuleAssociationProps(
+            resolver_rule_id=resolver_rule_id, vpc_id=vpc_id, name=name
+        )
 
         jsii.create(CfnResolverRuleAssociation, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnResolverRuleAssociation":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnResolverRuleAssociation":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -616,7 +807,9 @@ class CfnResolverRuleAssociation(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta,
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -630,7 +823,9 @@ class CfnResolverRuleAssociation(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta,
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -726,9 +921,19 @@ class CfnResolverRuleAssociation(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta,
         jsii.set(self, "name", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRuleAssociationProps", jsii_struct_bases=[], name_mapping={'resolver_rule_id': 'resolverRuleId', 'vpc_id': 'vpcId', 'name': 'name'})
-class CfnResolverRuleAssociationProps():
-    def __init__(self, *, resolver_rule_id: str, vpc_id: str, name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRuleAssociationProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "resolver_rule_id": "resolverRuleId",
+        "vpc_id": "vpcId",
+        "name": "name",
+    },
+)
+class CfnResolverRuleAssociationProps:
+    def __init__(
+        self, *, resolver_rule_id: str, vpc_id: str, name: typing.Optional[str] = None
+    ) -> None:
         """Properties for defining a ``AWS::Route53Resolver::ResolverRuleAssociation``.
 
         :param resolver_rule_id: ``AWS::Route53Resolver::ResolverRuleAssociation.ResolverRuleId``.
@@ -739,10 +944,11 @@ class CfnResolverRuleAssociationProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverruleassociation.html
         """
         self._values = {
-            'resolver_rule_id': resolver_rule_id,
-            'vpc_id': vpc_id,
+            "resolver_rule_id": resolver_rule_id,
+            "vpc_id": vpc_id,
         }
-        if name is not None: self._values["name"] = name
+        if name is not None:
+            self._values["name"] = name
 
     @builtins.property
     def resolver_rule_id(self) -> str:
@@ -751,7 +957,7 @@ class CfnResolverRuleAssociationProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverruleassociation.html#cfn-route53resolver-resolverruleassociation-resolverruleid
         """
-        return self._values.get('resolver_rule_id')
+        return self._values.get("resolver_rule_id")
 
     @builtins.property
     def vpc_id(self) -> str:
@@ -760,7 +966,7 @@ class CfnResolverRuleAssociationProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverruleassociation.html#cfn-route53resolver-resolverruleassociation-vpcid
         """
-        return self._values.get('vpc_id')
+        return self._values.get("vpc_id")
 
     @builtins.property
     def name(self) -> typing.Optional[str]:
@@ -769,7 +975,7 @@ class CfnResolverRuleAssociationProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverruleassociation.html#cfn-route53resolver-resolverruleassociation-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -778,12 +984,43 @@ class CfnResolverRuleAssociationProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnResolverRuleAssociationProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnResolverRuleAssociationProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRuleProps", jsii_struct_bases=[], name_mapping={'domain_name': 'domainName', 'rule_type': 'ruleType', 'name': 'name', 'resolver_endpoint_id': 'resolverEndpointId', 'tags': 'tags', 'target_ips': 'targetIps'})
-class CfnResolverRuleProps():
-    def __init__(self, *, domain_name: str, rule_type: str, name: typing.Optional[str]=None, resolver_endpoint_id: typing.Optional[str]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None, target_ips: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnResolverRule.TargetAddressProperty", _IResolvable_9ceae33e]]]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_route53resolver.CfnResolverRuleProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "domain_name": "domainName",
+        "rule_type": "ruleType",
+        "name": "name",
+        "resolver_endpoint_id": "resolverEndpointId",
+        "tags": "tags",
+        "target_ips": "targetIps",
+    },
+)
+class CfnResolverRuleProps:
+    def __init__(
+        self,
+        *,
+        domain_name: str,
+        rule_type: str,
+        name: typing.Optional[str] = None,
+        resolver_endpoint_id: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+        target_ips: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "CfnResolverRule.TargetAddressProperty", _IResolvable_9ceae33e
+                    ]
+                ],
+            ]
+        ] = None,
+    ) -> None:
         """Properties for defining a ``AWS::Route53Resolver::ResolverRule``.
 
         :param domain_name: ``AWS::Route53Resolver::ResolverRule.DomainName``.
@@ -797,13 +1034,17 @@ class CfnResolverRuleProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverrule.html
         """
         self._values = {
-            'domain_name': domain_name,
-            'rule_type': rule_type,
+            "domain_name": domain_name,
+            "rule_type": rule_type,
         }
-        if name is not None: self._values["name"] = name
-        if resolver_endpoint_id is not None: self._values["resolver_endpoint_id"] = resolver_endpoint_id
-        if tags is not None: self._values["tags"] = tags
-        if target_ips is not None: self._values["target_ips"] = target_ips
+        if name is not None:
+            self._values["name"] = name
+        if resolver_endpoint_id is not None:
+            self._values["resolver_endpoint_id"] = resolver_endpoint_id
+        if tags is not None:
+            self._values["tags"] = tags
+        if target_ips is not None:
+            self._values["target_ips"] = target_ips
 
     @builtins.property
     def domain_name(self) -> str:
@@ -812,7 +1053,7 @@ class CfnResolverRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverrule.html#cfn-route53resolver-resolverrule-domainname
         """
-        return self._values.get('domain_name')
+        return self._values.get("domain_name")
 
     @builtins.property
     def rule_type(self) -> str:
@@ -821,7 +1062,7 @@ class CfnResolverRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverrule.html#cfn-route53resolver-resolverrule-ruletype
         """
-        return self._values.get('rule_type')
+        return self._values.get("rule_type")
 
     @builtins.property
     def name(self) -> typing.Optional[str]:
@@ -830,7 +1071,7 @@ class CfnResolverRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverrule.html#cfn-route53resolver-resolverrule-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def resolver_endpoint_id(self) -> typing.Optional[str]:
@@ -839,7 +1080,7 @@ class CfnResolverRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverrule.html#cfn-route53resolver-resolverrule-resolverendpointid
         """
-        return self._values.get('resolver_endpoint_id')
+        return self._values.get("resolver_endpoint_id")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -848,16 +1089,27 @@ class CfnResolverRuleProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverrule.html#cfn-route53resolver-resolverrule-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     @builtins.property
-    def target_ips(self) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnResolverRule.TargetAddressProperty", _IResolvable_9ceae33e]]]]:
+    def target_ips(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union[
+                    "CfnResolverRule.TargetAddressProperty", _IResolvable_9ceae33e
+                ]
+            ],
+        ]
+    ]:
         """``AWS::Route53Resolver::ResolverRule.TargetIps``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53resolver-resolverrule.html#cfn-route53resolver-resolverrule-targetips
         """
-        return self._values.get('target_ips')
+        return self._values.get("target_ips")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -866,7 +1118,9 @@ class CfnResolverRuleProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnResolverRuleProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnResolverRuleProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
