@@ -10,11 +10,22 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IInspectable as _IInspectable_051e6ed8)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnDomain(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_sdb.CfnDomain"):
+class CfnDomain(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_sdb.CfnDomain",
+):
     """A CloudFormation ``AWS::SDB::Domain``.
 
     see
@@ -22,7 +33,14 @@ class CfnDomain(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
     cloudformationResource:
     :cloudformationResource:: AWS::SDB::Domain
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, description: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        description: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::SDB::Domain``.
 
         :param scope: - scope in which this resource is defined.
@@ -35,7 +53,14 @@ class CfnDomain(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnDomain":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnDomain":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -50,7 +75,9 @@ class CfnDomain(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -64,7 +91,9 @@ class CfnDomain(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -96,9 +125,13 @@ class CfnDomain(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
         jsii.set(self, "description", value)
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_sdb.CfnDomainProps", jsii_struct_bases=[], name_mapping={'description': 'description'})
-class CfnDomainProps():
-    def __init__(self, *, description: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_sdb.CfnDomainProps",
+    jsii_struct_bases=[],
+    name_mapping={"description": "description"},
+)
+class CfnDomainProps:
+    def __init__(self, *, description: typing.Optional[str] = None) -> None:
         """Properties for defining a ``AWS::SDB::Domain``.
 
         :param description: ``AWS::SDB::Domain.Description``.
@@ -106,9 +139,9 @@ class CfnDomainProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-simpledb.html
         """
-        self._values = {
-        }
-        if description is not None: self._values["description"] = description
+        self._values = {}
+        if description is not None:
+            self._values["description"] = description
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -117,7 +150,7 @@ class CfnDomainProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-simpledb.html#cfn-sdb-domain-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -126,7 +159,9 @@ class CfnDomainProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnDomainProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnDomainProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
