@@ -10,11 +10,25 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, TagManager as _TagManager_2508893f, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, CfnTag as _CfnTag_b4661f1a)
+from .. import (
+    CfnResource as _CfnResource_7760e8e4,
+    Construct as _Construct_f50a3f53,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
+    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
+    ICfnFinder as _ICfnFinder_3b168f30,
+    TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
+    IInspectable as _IInspectable_051e6ed8,
+)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
-class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_workspaces.CfnWorkspace"):
+class CfnWorkspace(
+    _CfnResource_7760e8e4,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_workspaces.CfnWorkspace",
+):
     """A CloudFormation ``AWS::WorkSpaces::Workspace``.
 
     see
@@ -22,7 +36,27 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
     cloudformationResource:
     :cloudformationResource:: AWS::WorkSpaces::Workspace
     """
-    def __init__(self, scope: _Construct_f50a3f53, id: str, *, bundle_id: str, directory_id: str, user_name: str, root_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None, user_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, volume_encryption_key: typing.Optional[str]=None, workspace_properties: typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]]=None) -> None:
+
+    def __init__(
+        self,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        bundle_id: str,
+        directory_id: str,
+        user_name: str,
+        root_volume_encryption_enabled: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+        user_volume_encryption_enabled: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        volume_encryption_key: typing.Optional[str] = None,
+        workspace_properties: typing.Optional[
+            typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]
+        ] = None,
+    ) -> None:
         """Create a new ``AWS::WorkSpaces::Workspace``.
 
         :param scope: - scope in which this resource is defined.
@@ -36,13 +70,29 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         :param volume_encryption_key: ``AWS::WorkSpaces::Workspace.VolumeEncryptionKey``.
         :param workspace_properties: ``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
         """
-        props = CfnWorkspaceProps(bundle_id=bundle_id, directory_id=directory_id, user_name=user_name, root_volume_encryption_enabled=root_volume_encryption_enabled, tags=tags, user_volume_encryption_enabled=user_volume_encryption_enabled, volume_encryption_key=volume_encryption_key, workspace_properties=workspace_properties)
+        props = CfnWorkspaceProps(
+            bundle_id=bundle_id,
+            directory_id=directory_id,
+            user_name=user_name,
+            root_volume_encryption_enabled=root_volume_encryption_enabled,
+            tags=tags,
+            user_volume_encryption_enabled=user_volume_encryption_enabled,
+            volume_encryption_key=volume_encryption_key,
+            workspace_properties=workspace_properties,
+        )
 
         jsii.create(CfnWorkspace, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnWorkspace":
+    def from_cloud_formation(
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: _ICfnFinder_3b168f30,
+    ) -> "CfnWorkspace":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -57,7 +107,9 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         """
         options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
@@ -71,7 +123,9 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -142,7 +196,9 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
 
     @builtins.property
     @jsii.member(jsii_name="rootVolumeEncryptionEnabled")
-    def root_volume_encryption_enabled(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def root_volume_encryption_enabled(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
 
         see
@@ -151,12 +207,16 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.get(self, "rootVolumeEncryptionEnabled")
 
     @root_volume_encryption_enabled.setter
-    def root_volume_encryption_enabled(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def root_volume_encryption_enabled(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "rootVolumeEncryptionEnabled", value)
 
     @builtins.property
     @jsii.member(jsii_name="userVolumeEncryptionEnabled")
-    def user_volume_encryption_enabled(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def user_volume_encryption_enabled(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
 
         see
@@ -165,7 +225,9 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.get(self, "userVolumeEncryptionEnabled")
 
     @user_volume_encryption_enabled.setter
-    def user_volume_encryption_enabled(self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]) -> None:
+    def user_volume_encryption_enabled(
+        self, value: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]
+    ) -> None:
         jsii.set(self, "userVolumeEncryptionEnabled", value)
 
     @builtins.property
@@ -184,7 +246,11 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
 
     @builtins.property
     @jsii.member(jsii_name="workspaceProperties")
-    def workspace_properties(self) -> typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]]:
+    def workspace_properties(
+        self,
+    ) -> typing.Optional[
+        typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
         see
@@ -193,12 +259,37 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
         return jsii.get(self, "workspaceProperties")
 
     @workspace_properties.setter
-    def workspace_properties(self, value: typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]]) -> None:
+    def workspace_properties(
+        self,
+        value: typing.Optional[
+            typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
         jsii.set(self, "workspaceProperties", value)
 
-    @jsii.data_type(jsii_type="monocdk-experiment.aws_workspaces.CfnWorkspace.WorkspacePropertiesProperty", jsii_struct_bases=[], name_mapping={'compute_type_name': 'computeTypeName', 'root_volume_size_gib': 'rootVolumeSizeGib', 'running_mode': 'runningMode', 'running_mode_auto_stop_timeout_in_minutes': 'runningModeAutoStopTimeoutInMinutes', 'user_volume_size_gib': 'userVolumeSizeGib'})
-    class WorkspacePropertiesProperty():
-        def __init__(self, *, compute_type_name: typing.Optional[str]=None, root_volume_size_gib: typing.Optional[jsii.Number]=None, running_mode: typing.Optional[str]=None, running_mode_auto_stop_timeout_in_minutes: typing.Optional[jsii.Number]=None, user_volume_size_gib: typing.Optional[jsii.Number]=None) -> None:
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_workspaces.CfnWorkspace.WorkspacePropertiesProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "compute_type_name": "computeTypeName",
+            "root_volume_size_gib": "rootVolumeSizeGib",
+            "running_mode": "runningMode",
+            "running_mode_auto_stop_timeout_in_minutes": "runningModeAutoStopTimeoutInMinutes",
+            "user_volume_size_gib": "userVolumeSizeGib",
+        },
+    )
+    class WorkspacePropertiesProperty:
+        def __init__(
+            self,
+            *,
+            compute_type_name: typing.Optional[str] = None,
+            root_volume_size_gib: typing.Optional[jsii.Number] = None,
+            running_mode: typing.Optional[str] = None,
+            running_mode_auto_stop_timeout_in_minutes: typing.Optional[
+                jsii.Number
+            ] = None,
+            user_volume_size_gib: typing.Optional[jsii.Number] = None,
+        ) -> None:
             """
             :param compute_type_name: ``CfnWorkspace.WorkspacePropertiesProperty.ComputeTypeName``.
             :param root_volume_size_gib: ``CfnWorkspace.WorkspacePropertiesProperty.RootVolumeSizeGib``.
@@ -209,13 +300,19 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html
             """
-            self._values = {
-            }
-            if compute_type_name is not None: self._values["compute_type_name"] = compute_type_name
-            if root_volume_size_gib is not None: self._values["root_volume_size_gib"] = root_volume_size_gib
-            if running_mode is not None: self._values["running_mode"] = running_mode
-            if running_mode_auto_stop_timeout_in_minutes is not None: self._values["running_mode_auto_stop_timeout_in_minutes"] = running_mode_auto_stop_timeout_in_minutes
-            if user_volume_size_gib is not None: self._values["user_volume_size_gib"] = user_volume_size_gib
+            self._values = {}
+            if compute_type_name is not None:
+                self._values["compute_type_name"] = compute_type_name
+            if root_volume_size_gib is not None:
+                self._values["root_volume_size_gib"] = root_volume_size_gib
+            if running_mode is not None:
+                self._values["running_mode"] = running_mode
+            if running_mode_auto_stop_timeout_in_minutes is not None:
+                self._values[
+                    "running_mode_auto_stop_timeout_in_minutes"
+                ] = running_mode_auto_stop_timeout_in_minutes
+            if user_volume_size_gib is not None:
+                self._values["user_volume_size_gib"] = user_volume_size_gib
 
         @builtins.property
         def compute_type_name(self) -> typing.Optional[str]:
@@ -224,7 +321,7 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-computetypename
             """
-            return self._values.get('compute_type_name')
+            return self._values.get("compute_type_name")
 
         @builtins.property
         def root_volume_size_gib(self) -> typing.Optional[jsii.Number]:
@@ -233,7 +330,7 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-rootvolumesizegib
             """
-            return self._values.get('root_volume_size_gib')
+            return self._values.get("root_volume_size_gib")
 
         @builtins.property
         def running_mode(self) -> typing.Optional[str]:
@@ -242,16 +339,18 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-runningmode
             """
-            return self._values.get('running_mode')
+            return self._values.get("running_mode")
 
         @builtins.property
-        def running_mode_auto_stop_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
+        def running_mode_auto_stop_timeout_in_minutes(
+            self,
+        ) -> typing.Optional[jsii.Number]:
             """``CfnWorkspace.WorkspacePropertiesProperty.RunningModeAutoStopTimeoutInMinutes``.
 
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-runningmodeautostoptimeoutinminutes
             """
-            return self._values.get('running_mode_auto_stop_timeout_in_minutes')
+            return self._values.get("running_mode_auto_stop_timeout_in_minutes")
 
         @builtins.property
         def user_volume_size_gib(self) -> typing.Optional[jsii.Number]:
@@ -260,7 +359,7 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-workspaces-workspace-workspaceproperties.html#cfn-workspaces-workspace-workspaceproperties-uservolumesizegib
             """
-            return self._values.get('user_volume_size_gib')
+            return self._values.get("user_volume_size_gib")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -269,13 +368,46 @@ class CfnWorkspace(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="mo
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'WorkspacePropertiesProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "WorkspacePropertiesProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="monocdk-experiment.aws_workspaces.CfnWorkspaceProps", jsii_struct_bases=[], name_mapping={'bundle_id': 'bundleId', 'directory_id': 'directoryId', 'user_name': 'userName', 'root_volume_encryption_enabled': 'rootVolumeEncryptionEnabled', 'tags': 'tags', 'user_volume_encryption_enabled': 'userVolumeEncryptionEnabled', 'volume_encryption_key': 'volumeEncryptionKey', 'workspace_properties': 'workspaceProperties'})
-class CfnWorkspaceProps():
-    def __init__(self, *, bundle_id: str, directory_id: str, user_name: str, root_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, tags: typing.Optional[typing.List[_CfnTag_b4661f1a]]=None, user_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]=None, volume_encryption_key: typing.Optional[str]=None, workspace_properties: typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_workspaces.CfnWorkspaceProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "bundle_id": "bundleId",
+        "directory_id": "directoryId",
+        "user_name": "userName",
+        "root_volume_encryption_enabled": "rootVolumeEncryptionEnabled",
+        "tags": "tags",
+        "user_volume_encryption_enabled": "userVolumeEncryptionEnabled",
+        "volume_encryption_key": "volumeEncryptionKey",
+        "workspace_properties": "workspaceProperties",
+    },
+)
+class CfnWorkspaceProps:
+    def __init__(
+        self,
+        *,
+        bundle_id: str,
+        directory_id: str,
+        user_name: str,
+        root_volume_encryption_enabled: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
+        user_volume_encryption_enabled: typing.Optional[
+            typing.Union[bool, _IResolvable_9ceae33e]
+        ] = None,
+        volume_encryption_key: typing.Optional[str] = None,
+        workspace_properties: typing.Optional[
+            typing.Union[
+                "CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e
+            ]
+        ] = None,
+    ) -> None:
         """Properties for defining a ``AWS::WorkSpaces::Workspace``.
 
         :param bundle_id: ``AWS::WorkSpaces::Workspace.BundleId``.
@@ -291,15 +423,24 @@ class CfnWorkspaceProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html
         """
         self._values = {
-            'bundle_id': bundle_id,
-            'directory_id': directory_id,
-            'user_name': user_name,
+            "bundle_id": bundle_id,
+            "directory_id": directory_id,
+            "user_name": user_name,
         }
-        if root_volume_encryption_enabled is not None: self._values["root_volume_encryption_enabled"] = root_volume_encryption_enabled
-        if tags is not None: self._values["tags"] = tags
-        if user_volume_encryption_enabled is not None: self._values["user_volume_encryption_enabled"] = user_volume_encryption_enabled
-        if volume_encryption_key is not None: self._values["volume_encryption_key"] = volume_encryption_key
-        if workspace_properties is not None: self._values["workspace_properties"] = workspace_properties
+        if root_volume_encryption_enabled is not None:
+            self._values[
+                "root_volume_encryption_enabled"
+            ] = root_volume_encryption_enabled
+        if tags is not None:
+            self._values["tags"] = tags
+        if user_volume_encryption_enabled is not None:
+            self._values[
+                "user_volume_encryption_enabled"
+            ] = user_volume_encryption_enabled
+        if volume_encryption_key is not None:
+            self._values["volume_encryption_key"] = volume_encryption_key
+        if workspace_properties is not None:
+            self._values["workspace_properties"] = workspace_properties
 
     @builtins.property
     def bundle_id(self) -> str:
@@ -308,7 +449,7 @@ class CfnWorkspaceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-bundleid
         """
-        return self._values.get('bundle_id')
+        return self._values.get("bundle_id")
 
     @builtins.property
     def directory_id(self) -> str:
@@ -317,7 +458,7 @@ class CfnWorkspaceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-directoryid
         """
-        return self._values.get('directory_id')
+        return self._values.get("directory_id")
 
     @builtins.property
     def user_name(self) -> str:
@@ -326,16 +467,18 @@ class CfnWorkspaceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-username
         """
-        return self._values.get('user_name')
+        return self._values.get("user_name")
 
     @builtins.property
-    def root_volume_encryption_enabled(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def root_volume_encryption_enabled(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-rootvolumeencryptionenabled
         """
-        return self._values.get('root_volume_encryption_enabled')
+        return self._values.get("root_volume_encryption_enabled")
 
     @builtins.property
     def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
@@ -344,16 +487,18 @@ class CfnWorkspaceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-tags
         """
-        return self._values.get('tags')
+        return self._values.get("tags")
 
     @builtins.property
-    def user_volume_encryption_enabled(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+    def user_volume_encryption_enabled(
+        self,
+    ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-uservolumeencryptionenabled
         """
-        return self._values.get('user_volume_encryption_enabled')
+        return self._values.get("user_volume_encryption_enabled")
 
     @builtins.property
     def volume_encryption_key(self) -> typing.Optional[str]:
@@ -362,16 +507,20 @@ class CfnWorkspaceProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-volumeencryptionkey
         """
-        return self._values.get('volume_encryption_key')
+        return self._values.get("volume_encryption_key")
 
     @builtins.property
-    def workspace_properties(self) -> typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]]:
+    def workspace_properties(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]
+    ]:
         """``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-workspaces-workspace.html#cfn-workspaces-workspace-workspaceproperties
         """
-        return self._values.get('workspace_properties')
+        return self._values.get("workspace_properties")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -380,7 +529,9 @@ class CfnWorkspaceProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnWorkspaceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnWorkspaceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
