@@ -183,6 +183,16 @@ class FactName(
         """
         return jsii.sget(cls, "DOMAIN_SUFFIX")
 
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="ELBV2_ACCOUNT")
+    def ELBV2_ACCOUNT(cls) -> str:
+        """The account for ELBv2 in this region.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sget(cls, "ELBV2_ACCOUNT")
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="PARTITION")
     def PARTITION(cls) -> str:
@@ -260,7 +270,7 @@ class IFact(jsii.compat.Protocol):
 
     @builtins.property
     @jsii.member(jsii_name="value")
-    def value(self) -> str:
+    def value(self) -> typing.Optional[str]:
         """The value of this fact.
 
         stability
@@ -302,7 +312,7 @@ class _IFactProxy:
 
     @builtins.property
     @jsii.member(jsii_name="value")
-    def value(self) -> str:
+    def value(self) -> typing.Optional[str]:
         """The value of this fact.
 
         stability
@@ -387,6 +397,16 @@ class RegionInfo(
         """
         return jsii.get(self, "domainSuffix")
 
+    @builtins.property
+    @jsii.member(jsii_name="elbv2Account")
+    def elbv2_account(self) -> typing.Optional[str]:
+        """The account ID for ELBv2 in this region.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "elbv2Account")
+
     @builtins.property
     @jsii.member(jsii_name="partition")
     def partition(self) -> typing.Optional[str]:
